#line 1 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/commentcnv.cpp"
#include <stdint.h>

#line 4 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/commentcnv.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define commentcnvYY_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer commentcnvYY_create_buffer
#endif

#ifdef yy_delete_buffer
#define commentcnvYY_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer commentcnvYY_delete_buffer
#endif

#ifdef yy_scan_buffer
#define commentcnvYY_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer commentcnvYY_scan_buffer
#endif

#ifdef yy_scan_string
#define commentcnvYY_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string commentcnvYY_scan_string
#endif

#ifdef yy_scan_bytes
#define commentcnvYY_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes commentcnvYY_scan_bytes
#endif

#ifdef yy_init_buffer
#define commentcnvYY_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer commentcnvYY_init_buffer
#endif

#ifdef yy_flush_buffer
#define commentcnvYY_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer commentcnvYY_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define commentcnvYY_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state commentcnvYY_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define commentcnvYY_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer commentcnvYY_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define commentcnvYYpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state commentcnvYYpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define commentcnvYYpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state commentcnvYYpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define commentcnvYYensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack commentcnvYYensure_buffer_stack
#endif

#ifdef yylex
#define commentcnvYYlex_ALREADY_DEFINED
#else
#define yylex commentcnvYYlex
#endif

#ifdef yyrestart
#define commentcnvYYrestart_ALREADY_DEFINED
#else
#define yyrestart commentcnvYYrestart
#endif

#ifdef yylex_init
#define commentcnvYYlex_init_ALREADY_DEFINED
#else
#define yylex_init commentcnvYYlex_init
#endif

#ifdef yylex_init_extra
#define commentcnvYYlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra commentcnvYYlex_init_extra
#endif

#ifdef yylex_destroy
#define commentcnvYYlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy commentcnvYYlex_destroy
#endif

#ifdef yyget_debug
#define commentcnvYYget_debug_ALREADY_DEFINED
#else
#define yyget_debug commentcnvYYget_debug
#endif

#ifdef yyset_debug
#define commentcnvYYset_debug_ALREADY_DEFINED
#else
#define yyset_debug commentcnvYYset_debug
#endif

#ifdef yyget_extra
#define commentcnvYYget_extra_ALREADY_DEFINED
#else
#define yyget_extra commentcnvYYget_extra
#endif

#ifdef yyset_extra
#define commentcnvYYset_extra_ALREADY_DEFINED
#else
#define yyset_extra commentcnvYYset_extra
#endif

#ifdef yyget_in
#define commentcnvYYget_in_ALREADY_DEFINED
#else
#define yyget_in commentcnvYYget_in
#endif

#ifdef yyset_in
#define commentcnvYYset_in_ALREADY_DEFINED
#else
#define yyset_in commentcnvYYset_in
#endif

#ifdef yyget_out
#define commentcnvYYget_out_ALREADY_DEFINED
#else
#define yyget_out commentcnvYYget_out
#endif

#ifdef yyset_out
#define commentcnvYYset_out_ALREADY_DEFINED
#else
#define yyset_out commentcnvYYset_out
#endif

#ifdef yyget_leng
#define commentcnvYYget_leng_ALREADY_DEFINED
#else
#define yyget_leng commentcnvYYget_leng
#endif

#ifdef yyget_text
#define commentcnvYYget_text_ALREADY_DEFINED
#else
#define yyget_text commentcnvYYget_text
#endif

#ifdef yyget_lineno
#define commentcnvYYget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno commentcnvYYget_lineno
#endif

#ifdef yyset_lineno
#define commentcnvYYset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno commentcnvYYset_lineno
#endif

#ifdef yyget_column
#define commentcnvYYget_column_ALREADY_DEFINED
#else
#define yyget_column commentcnvYYget_column
#endif

#ifdef yyset_column
#define commentcnvYYset_column_ALREADY_DEFINED
#else
#define yyset_column commentcnvYYset_column
#endif

#ifdef yywrap
#define commentcnvYYwrap_ALREADY_DEFINED
#else
#define yywrap commentcnvYYwrap
#endif

#ifdef yyalloc
#define commentcnvYYalloc_ALREADY_DEFINED
#else
#define yyalloc commentcnvYYalloc
#endif

#ifdef yyrealloc
#define commentcnvYYrealloc_ALREADY_DEFINED
#else
#define yyrealloc commentcnvYYrealloc
#endif

#ifdef yyfree
#define commentcnvYYfree_ALREADY_DEFINED
#else
#define yyfree commentcnvYYfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define commentcnvYYwrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 98
#define YY_END_OF_BUFFER 99
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[624] =
    {   0,
        2,    2,   51,   51,   51,   51,   39,   39,   39,   39,
       78,   78,   99,   97,   98,   98,    2,   32,   97,   98,
        3,   32,   97,   98,   11,   98,   32,   97,   98,    9,
       32,   97,   98,   19,   32,   97,   98,   10,   32,   97,
       98,    2,   32,   97,   98,   32,   97,   98,    2,   32,
       97,   98,   32,   97,   98,    2,   32,   97,   98,    1,
        2,   32,   97,   98,   32,   97,   98,   45,   97,   98,
       46,   98,   44,   45,   97,   98,   45,   97,   98,   49,
       97,   98,   50,   98,   48,   49,   97,   98,   49,   97,
       98,   74,   98,   97,   98,   97,   98,   51,   60,   97,

       98,   54,   98,   60,   97,   98,   60,   97,   98,   52,
       60,   97,   98,   51,   60,   97,   98,   60,   97,   98,
       60,   97,   98,   60,   97,   98,   51,   60,   97,   98,
       60,   97,   98,   51,   60,   97,   98,   60,   97,   98,
       60,   97,   98,   60,   97,   98,   60,   97,   98,   39,
       42,   97,   98,   40,   98,   42,   97,   98,   42,   97,
       98,   39,   42,   97,   98,   42,   97,   98,   42,   97,
       98,   42,   97,   98,   34,   42,   97,   98,   35,   42,
       97,   98,   42,   97,   98,   39,   42,   97,   98,   42,
       97,   98,   78,   96,   97,   98,   79,   98,   77,   96,

       97,   98,   78,   96,   97,   98,   96,   97,   98,   78,
       96,   97,   98,   96,   97,   98,   78,   96,   97,   98,
       78,   96,   97,   98,   78,   96,   97,   98,   78,   96,
       97,   98,   85,   97,   98,   83,   85,   97,   98,   90,
       95,   97,   98,   92,   98,   95,   97,   98,   91,   95,
       97,   98,   93,   95,   97,   98,   94,   95,   97,   98,
       90,   95,   97,   98,   90,   95,   97,   98,    2,    7,
       22,   19,    2,    8,    2,    1,    2,   18,    1,    2,
        2,    2,    2,    2,    2,    1,    1,    2,    1,    2,
        1,    2,   30,   31,   43,   47,   51,   59,   57,   58,

       52,   52,   56,   51,   55,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   86,   51,   51,   39,
       39,   39,   38,   78,   79,   76,   78,   78,   78,   78,
       78,   78,   78,   78,   78,   83,   90,   89,   90,   90,
       90,    5,    7,    6,    8,    2,   20,   21,    1,    1,
        2,    2,    1,    2,   18,   18,   16,16397,    1,    1,
        1,    2,    1,    2,    2,    2,    1,    2,    1,    2,
        1,    2,    1,    1,    1,    1,    2,   66,   53,   80,
       86,   87,   86,   86,   86,   28,   28,   87,   86,   86,
       86,   86,   86,   86,   86,   86,   51,   26,   26,   33,

       41,   36,   36,   38,   75,   78,   78,   26,   78,   26,
       78,   90,16472,    4,   20,    1,    1,    2,    1,    2,
       17,   16,   16,16397,    1,    1,    1,    2,    1,    1,
        2,    2,    1,    2,    1,    2,    1,    2,    1,    2,
        1,    2,    1,   69,16452,16451,16456,16447,   61,   80,
       80,   86,   86,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   51,   26,   26,   36,   36,   78,   78,
       26,   78,   26,   78, 8280,   90, 8280,    1,    1,    1,
        2,   16,    1,    2,    2,    1,    1,    2,    1,    2,
    16455,16455,16454,16455,16457,16449,16449,   62,16449,16449,

     8260, 8259, 8264, 8255,   86,   86,   27,   27,   87,   86,
       86,   86,   86,   86,   86,   86,   86,   51,   78,   78,
        1,    2,    1,    2,    1,    1,    2,    1,    1,    1,
        2,    1,    2, 8263, 8262, 8265, 8257,   23,   81,   81,
       81,   84,   81,   87,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   51,   78,   78,    1,    1,    1,    2,
        1,    2,    1,    1,    1,    1,    2,    1,    2,    1,
        1,   64, 8263,   64, 8257,   84,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   51,   25,   37,   78,   78,
       12,   12,   12,    1,    1,   64, 8262,   24,   86,   86,

       86,   86,   86,   86,   86,   78,   15, 8205, 8205, 8205,
       15,   86,   82,   82,   87,   86,   29,   29,   87,   86,
       86,   14,   16
    } ;

static const flex_int16_t yy_accept[620] =
    {   0,
        1,    1,    1,    2,    3,    3,    3,    3,    3,    3,
        3,    4,    5,    6,    7,    8,    9,   10,   11,   12,
       13,   13,   13,   13,   13,   14,   16,   17,   21,   25,
       27,   30,   34,   38,   42,   46,   49,   53,   56,   60,
       65,   68,   71,   73,   77,   80,   83,   85,   89,   92,
       94,   96,   98,  102,  104,  107,  110,  114,  118,  121,
      124,  127,  131,  134,  138,  141,  144,  147,  150,  154,
      156,  159,  162,  166,  169,  172,  175,  179,  183,  186,
      190,  193,  197,  199,  203,  207,  210,  214,  217,  221,
      225,  229,  233,  236,  240,  244,  246,  249,  253,  257,

      261,  265,  269,  270,  270,  271,  272,  272,  273,  274,
      274,  275,  275,  276,  276,  278,  279,  279,  279,  281,
      282,  283,  284,  285,  286,  287,  289,  291,  293,  294,
      295,  296,  297,  297,  297,  297,  297,  297,  298,  299,
      299,  300,  301,  301,  302,  303,  304,  305,  305,  306,
      306,  306,  306,  306,  307,  308,  309,  310,  311,  312,
      313,  314,  315,  316,  317,  318,  319,  319,  320,  320,
      320,  320,  320,  320,  321,  321,  321,  322,  322,  322,
      322,  322,  322,  323,  323,  324,  325,  326,  327,  328,
      328,  329,  330,  331,  332,  333,  334,  335,  336,  337,

      338,  339,  340,  341,  342,  342,  344,  344,  344,  346,
      347,  348,  349,  350,  352,  353,  355,  356,  357,  357,
      358,  358,  358,  359,  360,  360,  360,  361,  363,  365,
      366,  366,  367,  368,  369,  371,  373,  374,  375,  376,
      378,  378,  379,  379,  379,  380,  380,  380,  380,  381,
      382,  383,  384,  385,  386,  387,  389,  390,  391,  392,
      393,  394,  395,  396,  397,  398,  398,  399,  400,  400,
      401,  402,  402,  403,  404,  405,  406,  407,  408,  410,
      412,  414,  415,  416,  417,  417,  418,  419,  419,  421,
      422,  422,  423,  423,  423,  424,  425,  426,  426,  427,

      429,  430,  432,  432,  433,  434,  435,  436,  437,  439,
      441,  443,  444,  445,  445,  445,  446,  447,  448,  449,
      450,  450,  450,  450,  450,  451,  452,  453,  454,  455,
      456,  457,  458,  459,  460,  461,  462,  463,  464,  465,
      465,  466,  467,  467,  467,  468,  469,  470,  471,  473,
      475,  477,  478,  479,  480,  482,  482,  482,  482,  482,
      483,  483,  483,  483,  483,  483,  484,  484,  485,  486,
      486,  487,  488,  489,  489,  491,  492,  493,  494,  495,
      496,  497,  498,  499,  499,  500,  501,  501,  502,  502,
      503,  503,  504,  504,  505,  505,  505,  505,  506,  507,

      508,  510,  511,  512,  513,  514,  515,  516,  517,  518,
      519,  519,  519,  519,  519,  519,  519,  519,  519,  519,
      519,  519,  519,  520,  521,  522,  522,  522,  522,  522,
      522,  522,  522,  522,  522,  523,  523,  525,  525,  526,
      528,  529,  530,  532,  534,  534,  535,  535,  535,  535,
      535,  536,  536,  536,  536,  537,  537,  538,  538,  538,
      538,  539,  539,  539,  540,  541,  543,  545,  546,  547,
      548,  549,  550,  551,  552,  553,  554,  555,  555,  555,
      555,  555,  555,  555,  555,  555,  555,  555,  555,  555,
      556,  557,  557,  557,  557,  557,  557,  557,  557,  558,

      559,  561,  563,  564,  565,  566,  568,  570,  571,  572,
      572,  572,  574,  574,  576,  576,  576,  576,  577,  578,
      579,  580,  581,  582,  583,  584,  585,  586,  587,  588,
      588,  588,  588,  588,  588,  588,  588,  588,  589,  590,
      591,  592,  593,  594,  594,  594,  594,  594,  594,  594,
      594,  595,  596,  596,  598,  599,  599,  600,  601,  602,
      603,  604,  605,  606,  606,  606,  606,  606,  606,  606,
      606,  607,  608,  608,  609,  610,  611,  612,  613,  614,
      616,  617,  618,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  621,  621,  621,  621,  621,  621,  621,  621,

      621,  622,  622,  622,  622,  622,  622,  622,  622,  622,
      622,  622,  622,  622,  622,  622,  622,  624,  624
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    9,    1,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       22,   22,   22,   22,   22,   23,   23,   24,   16,   25,
       16,   26,    1,   27,   28,   29,   30,   31,   32,   33,
       34,   34,   34,   34,   34,   35,   34,   34,   34,   36,
       34,   34,   34,   34,   37,   34,   34,   38,   34,   34,
       39,   40,   41,    1,   42,   43,   44,   45,   46,   47,

       48,   49,   34,   50,   51,   34,   52,   53,   54,   55,
       56,   36,   34,   57,   58,   59,   60,   61,   34,   62,
       63,   34,   64,   65,   66,   67,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[68] =
    {   0,
        1,    2,    3,    1,    4,    5,    6,    7,    1,    8,
        9,    8,    8,   10,   11,    7,   12,   13,   14,   15,
       15,   15,   15,    1,   16,    1,   17,   18,   18,   18,
       18,   18,   18,   19,   19,   18,   19,   19,    1,   20,
        1,   21,   22,   18,   18,   18,   18,   18,   18,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   23,    8,   24,   25
    } ;

static const flex_int16_t yy_base[707] =
    {   0,
     1815, 1814,    0,   45,   29,   30,    1,   31, 1813,   24,
       91,  157,   17,   18,  161,  165,  170,  176,  243,  172,
      310,  377,  169,  342, 1814, 4391, 4391,    0, 4391, 4391,
      160, 1806, 1798, 4391,  443, 1788,   56,   35,  473,  525,
       32, 4391, 4391, 4391,    0, 4391, 4391, 4391,    0,  188,
      336, 1785,    0,  194, 4391, 1796,   41,  585,   69, 1744,
      625,  687, 1770,  328,  355, 1753, 1728,   46,    0, 4391,
     4391,   41,  360, 1775, 1745, 1749, 4391, 4391, 1724,  364,
     1768, 1783, 4391, 1765,  753, 1769,  820,  861,  923,  370,
      179,    7, 4391,    0,    0, 4391, 1763, 4391, 4391, 4391,

      392, 1761,    0, 1776, 4391, 1775, 1770, 4391,  989, 1772,
     4391, 1771, 1028, 1767, 1058,  155,  340,  408,  455,  502,
      444,  155,  544, 1111, 1168, 1218,  159,  185, 4391, 4391,
     4391, 4391,  405, 1753,  433, 1752,  381,    0, 4391,  453,
     4391, 4391, 1763,  146,  204, 4391, 1725,    0, 4391,  207,
     1741,  288,    0, 1702,  142,  256,  267,  403,  264,  127,
      389,  299,  350,  166,  288,   36, 1717,  496,  510, 1718,
     1693, 1716, 1691,    0, 1702,  517,  495, 1737,    9, 1696,
     1705, 1679,  514, 1726,  321, 1741, 4391, 4391, 1698, 1727,
     1278, 1345,  381,  539,  396,  367,  420,  418,    0,    0,

     4391,  535, 1721,  348, 1735, 4391, 1731, 1727, 4391, 1411,
        0, 4391, 1441, 1484,  593,    0, 4391, 1710, 1725, 4391,
     1723,  471,  549,  600,  607,  621,  636,  697,  460,  549,
      582,  762, 1711, 1518, 1567, 1624, 1663,  457,  464,    0,
      573, 1696, 1712,  571, 4391, 1701,    0,  190,   33, 1654,
     4391,  630,  492,  485, 4391, 4391,  553,  516,  372,  463,
      341,  555,  527,  581, 1723, 1661, 1672, 1647, 1666, 4391,
     4391, 1665, 1667, 1642, 4391, 4391,  616,  587,  658,  597,
      666, 4391,    0,    0,  718, 4391,  701,  726,  827, 4391,
     1704,  688,  673, 1703,  769,  643,    0,  844,  933,  950,

      716,  723,  993, 1039, 1694, 1779, 1818, 1667,    0,    0,
      783, 4391,  873, 1694, 1046, 1698, 1696, 1694, 1693, 4391,
      706,    0, 1676,  502,  526,  661,  703,  723,  744, 1881,
      646,  617,  727,  686,  712,  648,  745,  737, 1948, 1646,
     1649, 1624,  842,  939, 1646, 1620, 2014, 2081,  796,  804,
      876,    0, 1173, 1212, 1287,  832, 1663,   28, 1677,  838,
     1676,  851,  941,  783, 1371,  861,  328,    0, 1002, 1631,
        0, 1237,  954,  989, 1422, 1662, 1180, 1222,  807, 1661,
     1660, 1272, 4391,  839, 1336,  891, 1659, 4391, 1658, 4391,
     1656, 4391, 1655, 4391, 1633,    0,  610, 2148,  827, 4391,

     4391,  856,  881,  750,  914,  963,  899,  877,  977, 2215,
     1602, 1593, 1589, 1599, 1597, 1581, 1591, 1584, 1581, 1580,
     1549, 1532,  782,  757, 1447, 1001,  956, 1035, 1565, 1051,
     1564, 1086, 1027, 1079, 1062, 1096, 1655, 1041, 2271, 1732,
     1890,    0, 1957,    0, 1572, 4391, 1363,  914, 1571, 1375,
     4391,  935, 1570, 1569, 4391, 1567, 4391, 1394, 1061, 1558,
     1542, 1541,  430, 4391, 1207, 4391, 4391, 1011, 1040, 1137,
     1187, 1023, 1044,  842,  920, 1045, 1157, 1212, 1512, 1503,
     1496, 1499, 1504, 1495, 1492, 1497, 1484, 1496, 1482, 1002,
      448,    0, 1291, 1396, 1054, 1250, 1212, 1445, 2157, 2224,

     2276,    0,    0, 1187, 2310, 2315,    0, 2349, 4391, 1527,
     1526, 4391, 1525, 4391, 1246, 1086, 1321, 4391,  524,  805,
     1166, 1182, 1204, 1237, 1133, 1212, 1250, 1217, 4391, 1481,
     1472, 1472, 1459, 1458, 1468, 1456, 1463, 4391, 1282, 1268,
     4391, 1451, 1444, 1481, 1437,  949,    0, 1482, 1496, 1267,
     2354, 4391, 1499, 4391, 4391, 1466, 1273, 2407, 1296, 1309,
     2474, 1311, 1331, 1436, 1432, 1419, 1424, 1422, 1422, 1410,
     1347, 4391, 1331, 4391, 1529, 1394, 1456, 1371, 4391, 4391,
     1344, 4391, 4391, 1398, 1384, 1369, 1334, 1279, 1269, 1263,
      313, 1376, 1245, 1239, 1187, 1136, 1067, 1052,  980, 1308,

     1368,  965,  920,  852,  814, 1402,  726,  653, 1378,  649,
     1446,  124, 1327, 1125,   10,    6, 4391, 4391, 2541, 2566,
     2591, 2616, 2641, 2666, 2691, 2716, 2741, 2766, 2791, 2816,
     2841, 2865, 2890, 2915, 2929, 2934, 2955, 2976, 3001, 3026,
     3050, 3071, 3096, 3121, 3146, 3171, 3196, 3221, 3235, 3239,
     3250, 3273, 3294, 3319, 3344, 3369, 3386, 3405, 3430, 3444,
     3455, 3475, 3482, 3505, 3529, 3554, 3579, 3604, 3629, 3654,
     3679, 3704, 3729, 3743, 3753, 3764, 3784, 3791, 3814, 3838,
     3863, 3888, 3913, 3938, 3963, 1509, 1423, 3980, 3999, 4024,
     4049, 4074, 4099, 4124, 4149, 4174, 4188, 4198, 4209, 4230,

     4255, 4269, 4290, 4315, 4340, 4365
    } ;

static const flex_int16_t yy_def[707] =
    {   0,
      619,  619,  620,  620,  621,  621,  622,  622,  619,  619,
      618,   11,   11,   11,  623,  623,  623,  623,  618,   19,
      624,  624,  625,  625,  618,  618,  618,  626,  618,  618,
      627,  618,  618,  618,  628,  618,  626,  618,  626,  626,
      618,  618,  618,  618,  629,  618,  618,  618,  630,  618,
      618,  618,  631,  632,  618,  618,  633,  634,  618,  635,
      636,  634,  618,  631,  618,  618,  618,  618,  637,  618,
      618,  618,  637,  618,  618,  618,  618,  618,  618,  637,
      618,  638,  618,  618,  639,  618,  640,  636,  639,  638,
      638,  638,  618,  641,  642,  618,  618,  618,  618,  618,

      642,  642,  626,  627,  618,  643,  618,  618,  628,  644,
      618,  645,  646,  647,  626,  618,  648,  618,  626,  626,
       39,  626,  626,  618,  618,  626,  626,  626,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  631,  618,  632,
      618,  618,  618,  633,  633,  618,   62,  649,  618,  618,
      635,  635,  650,  651,  651,  651,  651,  651,  651,  651,
      651,  651,  651,  651,  651,   62,  618,  631,  618,  618,
      618,  618,  618,  652,  618,  618,  652,  618,  618,  618,
      618,  618,  652,  618,  618,  638,  618,  618,   89,  618,
      653,  653,   89,  638,  638,  638,  638,  638,  641,  642,

      618,  642,  642,  642,  643,  618,  618,  645,  618,  646,
      654,  618,  618,  626,  626,  626,  618,  618,  648,  618,
      655,  648,  656,  618,  618,  618,  618,  626,  626,  626,
      618,  626,  657,  626,  618,  235,  618,  618,  618,  626,
      618,  658,  618,  659,  618,  649,  660,  661,  662,  663,
      618,  663,  663,  663,  618,  618,  663,  663,  663,  663,
      663,  663,  663,  663,  664,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  192,   89,  638,  638,
      665,  618,  654,  213,  618,  618,  626,  618,  626,  618,
      655,  618,  648,  666,  667,  656,  213,  618,  618,  626,

      618,  626,  618,  626,  657,  626,  618,  234,  235,  236,
      236,  618,  668,  618,  669,  670,  671,  672,  673,  618,
      618,  674,  675,  676,  618,  677,  678,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  678,  679,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  680,  680,
      681,  682,  618,  618,  626,  618,  618,  683,  684,  618,
      685,  685,  618,  685,  618,  618,  686,  306,  626,  687,
      307,  688,  626,  618,  236,  689,  689,  690,  689,  691,
      692,  692,  618,  618,  692,  692,  693,  618,  694,  618,
      695,  618,  696,  618,  697,  698,  699,  678,  678,  618,

      618,  678,  678,  678,  678,  678,  678,  678,  678,  679,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  347,  348,  618,  618,  683,  618,  618,  618,
      618,  685,  686,  618,  626,  618,  626,  686,  688,  626,
      618,  439,  236,  236,  689,  618,  689,  689,  690,  690,
      618,  690,  700,  691,  618,  692,  618,  692,  692,  701,
      697,  702,  699,  618,  618,  618,  618,  678,  678,  678,
      678,  678,  678,  678,  678,  678,  410,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  347,
      348,  703,  703,  618,  683,  618,  618,  685,  618,  618,

      626,  626,  439,  688,  618,  626,  626,  618,  618,  704,
      700,  618,  701,  618,  702,  699,  618,  618,  678,  678,
      678,  678,  678,  678,  678,  678,  678,  410,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  347,  348,
      618,  618,  618,  618,  618,  683,  705,  705,  685,  685,
      618,  618,  704,  618,  618,  699,  678,  678,  678,  678,
      678,  678,  678,  618,  618,  618,  618,  618,  618,  618,
      347,  618,  683,  618,  618,  618,  685,  678,  618,  618,
      678,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      683,  678,  618,  618,  618,  618,  618,  618,  618,  683,

      678,  618,  618,  618,  618,  683,  618,  618,  683,  618,
      683,  618,  683,  683,  706,  706,  618,    0,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,

      618,  618,  618,  618,  618,  618
    } ;

static const flex_int16_t yy_nxt[4459] =
    {   0,
      618,   29,   30,   47,   29,   31,   32,   33,  617,  187,
       34,   48,  617,   35,  271,   29,   36,   37,   38,   39,
       40,   40,   40,   55,   55,   51,   50,  271,   51,   35,
      220,   43,   43,   47,  325,   44,   44,  325,  129,   41,
       49,   48,   52,   68,   68,   35,   29,   30,  116,   29,
       31,   32,   33,  117,  145,   34,   68,   68,   35,  146,
       29,   36,   37,   38,   39,   40,   40,   40,   45,   45,
       49,  130,  153,  198,   35,  115,  115,  115,  115,  147,
       55,   55,  149,  427,   41,  153,  265,  150,  175,  176,
       35,   53,   53,   54,   53,   55,   55,   56,   53,   53,

       53,   53,   53,   53,   57,   58,   53,   58,   58,   59,
       58,   58,   58,   58,   53,   60,   53,   61,   58,   58,
       58,   58,   58,   58,   58,   58,   58,   58,   58,   53,
       61,   53,   58,   55,   58,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   62,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   63,   53,   53,   55,   64,  618,
      217,   65,  105,   70,  618,  106,   73,   70,  218,   73,
      258,   96,   70,   90,  229,  229,   90,   80,   70,   71,
       80,  187,   97,   74,  106,  106,  270,   72,   71,  133,
      251,   72,  133,  240,   81,  140,   75,  252,  140,   66,

       72,  141,   75,   71,   72,  251,  134,   71,   98,   75,
      142,  240,   76,  263,   91,   75,  247,  145,   76,  127,
      149,  197,  146,   67,   71,  150,   71,   71,   71,  251,
       71,   71,   99,   77,  100,   78,   79,  127,   92,   77,
      324,   78,   79,   82,   82,   83,   82,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   84,   85,   82,   85,
       85,   86,   85,   85,   85,   85,   82,   87,   82,   88,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   82,   88,   82,   85,   82,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   89,   85,   85,   85,

       85,   85,   85,   85,   85,   85,   82,   82,   82,   82,
       93,  253,   27,   93,  247,  220,   93,   93,   93,  251,
       93,  254,  257,   93,   93,   93,  275,  251,   93,  168,
      251,  248,  169,   93,   93,   93,   93,  135,  367,  275,
      135,  264,  220,  101,   96,  221,  101,  222,   93,   93,
       93,  251,   93,  281,  136,   97,  169,  261,  223,  169,
      102,  177,  251,  434,  177,  183,  281,  600,  183,  187,
      170,  194,  187,   93,  194,   93,   93,   93,  178,   27,
       93,   98,  184,   93,   93,   93,  242,   93,  243,  335,
       93,   93,   93,  202,  171,   93,  202,  170,  187,  244,

       93,   93,   93,   93,  251,   99,  133,  100,  262,  133,
      203,  255,  195,  251,  255,   93,   93,   93,  118,   93,
      187,  171,  187,  134,  189,  224,  334,  225,  225,  225,
      225,  278,  259,  198,  135,  251,  196,  135,  197,  226,
       93,  255,   93,   93,  110,  111,  260,  110,  112,  110,
      110,  136,  251,  110,  140,  226,  247,  140,  110,  110,
      141,  110,  279,  121,  121,  121,  256,  113,  113,  142,
      301,  540,  103,  220,  115,  115,  115,  115,  293,  302,
      302,  103,  110,  118,  280,  516,  215,  216,  103,  216,
      119,  312,  120,  120,  120,  121,  177,  168,  238,  177,

      169,  122,  215,  216,  123,  103,  189,  216,  330,  312,
      124,  169,  227,  178,  169,  183,  238,  122,  183,  119,
      123,  228,  228,  228,  121,  270,  251,  325,  247,  270,
      325,  331,  184,  123,  124,  125,  202,  329,  170,  202,
      194,  187,  119,  194,  126,  126,  126,  126,  251,  123,
      330,  295,  170,  203,  397,  251,  123,  270,  230,  127,
      231,  128,  171,  232,  232,  232,  232,  296,  232,  232,
      232,  232,  123,  320,  333,  557,  171,  127,  313,  251,
      314,  195,  270,  337,  128,  138,  138,  251,  138,  321,
      251,  315,  138,  138,  138,  138,  138,  138,  336,  187,

      138,  298,  298,  298,  298,  196,  332,  287,  138,  288,
      138,  148,  289,  289,  289,  289,  251,  118,  251,  297,
      297,  297,  297,  138,  224,  138,  225,  225,  225,  225,
      189,  285,  286,  338,  286,  231,  247,  231,  226,  348,
      298,  298,  298,  298,  251,  295,  227,  285,  286,  138,
      138,  153,  286,  224,  226,  299,  299,  299,  225,  191,
      187,  296,  325,  350,  153,  325,  347,  226,  463,  403,
      155,  156,  157,  158,  159,  220,  327,  160,  161,  352,
      251,  162,  163,  226,  328,  164,  165,  138,  138,  356,
      138,  402,  356,  251,  138,  138,  138,  138,  138,  138,

      349,  612,  138,  358,  407,  352,  357,  227,  320,  251,
      138,  251,  138,  148,  119,  270,  300,  300,  300,  121,
      289,  289,  289,  289,  321,  138,  301,  138,  123,  352,
      166,  352,  288,  301,  288,  366,  366,  353,  353,  353,
      353,  405,  302,  302,  123,  353,  353,  353,  353,  251,
      330,  138,  138,  186,  186,  187,  186,  186,  186,  186,
      186,  186,  186,  186,  186,  186,  251,  406,  186,  398,
      362,  363,  303,  362,  404,  251,  186,  186,  186,  148,
      610,  304,  304,  304,  304,  363,  251,  364,  399,  408,
      251,  186,  409,  186,  216,  186,  216,  373,  187,  374,

      251,  432,  375,  375,  375,  375,  187,  251,  251,  446,
      216,  471,  491,  251,  216,  189,  186,  186,  186,  186,
      186,  186,  187,  186,  186,  186,  186,  186,  186,  186,
      186,  186,  186,  356,  191,  186,  356,  354,  349,  428,
      490,  383,  428,  186,  186,  186,  355,  355,  355,  355,
      357,  558,  362,  363,  303,  362,  429,  384,  186,  216,
      186,  216,  186,  365,  365,  365,  365,  270,  251,  364,
      350,  301,  453,  192,  377,  216,  286,  377,  286,  216,
      366,  366,  468,  186,  186,  186,  186,  153,  412,  352,
      251,  413,  286,  457,  414,  415,  286,  378,  416,  379,

      153,  525,  417,  418,  608,  251,  155,  156,  157,  158,
      159,  469,  379,  160,  161,  352,  446,  162,  163,  251,
      475,  164,  165,  186,  186,  187,  186,  186,  186,  186,
      186,  186,  186,  186,  186,  186,  470,  451,  186,  352,
      251,  352,  430,  227,  251,  430,  186,  186,  186,  148,
      224,  220,  299,  299,  299,  225,  460,  474,  220,  431,
      227,  186,  251,  186,  226,  186,  193,  119,  472,  300,
      300,  300,  121,  440,  440,  440,  440,  251,  526,  453,
      226,  123,  270,  251,  419,  420,  186,  186,  186,  186,
      110,  111,  421,  110,  110,  110,  110,  123,  422,  110,

      510,  495,  573,  303,  110,  110,  492,  110,  441,  441,
      441,  441,  365,  365,  365,  365,  435,  473,  436,  493,
      607,  437,  437,  437,  437,  286,  251,  286,  110,  208,
      209,  476,  208,  208,  208,  208,  428,  367,  208,  428,
      251,  286,  270,  208,  208,  286,  208,  382,  383,  303,
      382,  367,  430,  429,  191,  430,  220,  539,  304,  304,
      304,  304,  434,  457,  384,  494,  519,  208,  213,  431,
      385,  216,  386,  216,  251,  523,  434,  214,  214,  214,
      214,  437,  437,  437,  437,  386,  251,  216,  363,  215,
      216,  216,  216,  436,  520,  436,  524,  527,  499,  499,

      499,  499,  605,  251,  498,  215,  216,  251,  251,  556,
      216,  103,  247,  546,  103,  499,  499,  499,  499,  103,
      103,  233,  103,  103,  103,  103,  460,  220,  234,  270,
      235,  235,  235,  235,  103,  103,  103,  103,  235,  235,
      235,  235,  235,  235,  236,  236,  236,  236,  236,  103,
      498,  103,  103,  103,  235,  235,  235,  235,  235,  235,
      236,  236,  236,  236,  236,  236,  236,  236,  236,  236,
      236,  236,  236,  236,  103,  103,  103,  103,  125,  615,
      528,  447,  446,  354,  447,  224,  562,  237,  237,  237,
      237,  521,  425,  425,  425,  425,  251,  233,  270,  226,

      251,  618,  238,  618,  239,  286,  448,  286,  517,  518,
      517,  517,  147,  529,  529,  226,  529,  547,  559,  448,
      238,  286,  354,  450,  451,  286,  450,  239,  125,  251,
      547,  425,  425,  425,  425,  119,  560,  126,  126,  126,
      126,  604,  522,  618,  286,  251,  286,  233,  452,  123,
      251,  374,  127,  374,  128,  547,  439,  439,  439,  439,
      286,  452,  563,  396,  286,  123,  561,  251,  548,  363,
      127,  555,  147,  458,  457,  251,  458,  128,  186,  186,
      187,  186,  186,  186,  186,  186,  186,  186,  186,  186,
      186,  603,  542,  186,  618,  542,  602,  354,  459,  561,

      251,  186,  186,  186,  247,  571,  355,  355,  355,  355,
      220,  459,  561,  251,  494,  599,  186,  543,  186,  216,
      186,  216,  517,  518,  517,  517,  189,  598,  578,  220,
      543,  597,  577,  220,  191,  216,  251,  458,  457,  216,
      458,  186,  186,  186,  186,  186,  186,  187,  186,  186,
      186,  186,  186,  186,  186,  186,  186,  186,  561,  251,
      186,  581,  459,  330,  447,  446,  606,  447,  186,  186,
      186,  247,  251,  618,  251,  459,  450,  451,  591,  450,
      220,  303,  614,  186,  561,  186,  596,  186,  277,  448,
      365,  365,  365,  365,  251,  458,  457,  544,  458,  191,

      544,  452,  448,  286,  220,  286,  561,  251,  186,  186,
      186,  186,  208,  209,  452,  208,  208,  208,  208,  286,
      459,  208,  545,  286,  595,  592,  208,  208,  601,  208,
      561,  251,  442,  459,  251,  545,  611,  438,  594,  251,
      438,  443,  443,  443,  443,  609,  549,  363,  220,  549,
      208,  213,  544,  593,  444,  544,  444,  354,  363,  572,
      284,  284,  284,  284,  590,  589,  425,  425,  425,  425,
      444,  550,  285,  286,  444,  286,  588,  545,  587,  286,
      586,  286,  544,  575,  550,  544,  575,  585,  285,  286,
      545,  584,  618,  286,  213,  286,  613,  549,  363,  286,

      549,  554,  572,  214,  214,  214,  214,  545,  576,  572,
      538,  570,  569,  568,  567,  215,  216,  433,  216,  566,
      545,  576,  550,  433,  565,  564,  433,  514,  512,  554,
      544,  215,  216,  544,  538,  550,  216,  306,  306,  306,
      306,  538,  538,  537,  536,  306,  306,  306,  306,  306,
      306,  535,  534,  533,  532,  545,  531,  530,  396,  322,
      514,  306,  306,  306,  306,  306,  306,  103,  545,  457,
      103,  455,  512,  451,  446,  103,  103,  307,  103,  103,
      103,  103,  497,  496,  308,  489,  309,  309,  309,  309,
      103,  103,  103,  103,  309,  309,  309,  309,  309,  309,

      310,  310,  311,  310,  310,  103,  488,  103,  103,  103,
      309,  309,  309,  309,  309,  309,  310,  310,  310,  310,
      310,  310,  310,  310,  310,  310,  310,  310,  310,  310,
      103,  103,  103,  103,  233,  487,  486,  485,  484,  483,
      482,  103,  481,  310,  310,  310,  310,  480,  479,  478,
      322,  310,  310,  310,  310,  310,  310,  394,  392,  310,
      390,  388,  457,  455,  446,  500,  434,  310,  310,  310,
      310,  310,  310,  125,  501,  501,  501,  501,  363,  360,
      224,  426,  237,  237,  237,  237,  346,  502,  345,  502,
      342,  341,  411,  396,  226,  394,  392,  238,  390,  239,

      388,  380,  369,  502,  233,  360,  292,  502,  346,  345,
      226,  344,  343,  342,  341,  238,  340,  251,  322,  318,
      317,  233,  239,  138,  138,  292,  138,  220,  290,  209,
      138,  138,  138,  138,  138,  138,  282,  206,  138,  204,
      276,  189,  505,  187,  185,  274,  138,  273,  138,  148,
      272,  506,  506,  506,  506,  179,  269,  268,  267,  173,
      172,  138,  266,  138,  507,  251,  507,  247,  147,  245,
      137,  241,  212,  209,  111,  339,  207,  206,  105,  204,
      507,  201,  190,  188,  507,  187,  185,  138,  138,  367,
      182,  181,  180,  179,  173,  172,  167,  152,  368,  368,

      368,  368,  143,  137,  114,  108,  368,  368,  368,  368,
      368,  368,  107,  618,  369,   50,   27,   27,  618,  618,
      618,  618,  368,  368,  368,  368,  368,  368,  307,  618,
      618,  618,  618,  618,  618,  370,  618,  371,  371,  371,
      371,  618,  618,  618,  618,  371,  371,  371,  371,  371,
      371,  305,  305,  372,  305,  305,  618,  618,  618,  618,
      618,  371,  371,  371,  371,  371,  371,  305,  305,  305,
      305,  305,  305,  305,  305,  305,  305,  305,  305,  305,
      305,  400,  400,  400,  400,  400,  400,  400,  400,  400,
      400,  400,  400,  400,  400,  400,  400,  400,  400,  400,

      505,  618,  618,  618,  400,  400,  400,  400,  618,  508,
      508,  508,  508,  618,  618,  618,  618,  618,  618,  400,
      400,  400,  509,  400,  509,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  509,  618,
      618,  618,  509,  618,  401,  400,  400,  400,  138,  138,
      618,  138,  618,  618,  618,  138,  138,  138,  138,  138,
      138,  618,  618,  138,  618,  618,  618,  442,  618,  618,
      618,  138,  618,  138,  148,  618,  443,  443,  443,  443,
      618,  618,  618,  618,  618,  618,  138,  618,  138,  444,
      618,  444,  618,  618,  618,  618,  618,  618,  618,  618,

      618,  618,  618,  618,  618,  444,  410,  618,  618,  444,
      618,  618,  138,  138,  186,  186,  187,  186,  186,  186,
      186,  186,  186,  186,  186,  186,  186,  618,  191,  186,
      191,  191,  618,  191,  191,  191,  191,  186,  186,  186,
      247,  191,  191,  191,  191,  191,  191,  191,  191,  191,
      191,  191,  186,  618,  186,  191,  186,  191,  191,  191,
      191,  191,  191,  191,  191,  191,  423,  191,  191,  191,
      191,  191,  191,  191,  191,  191,  191,  186,  186,  186,
      186,  186,  186,  187,  186,  186,  186,  186,  186,  186,
      186,  186,  186,  186,  618,  189,  186,  189,  189,  618,

      189,  189,  189,  189,  186,  186,  186,  148,  189,  189,
      189,  189,  189,  189,  189,  189,  189,  189,  189,  186,
      618,  186,  189,  186,  189,  189,  189,  189,  189,  189,
      189,  189,  189,  189,  189,  189,  189,  189,  189,  424,
      189,  189,  189,  189,  186,  186,  186,  186,  464,  465,
      466,  465,  465,  464,  464,  464,  464,  464,  464,  464,
      464,  464,  464,  464,  464,  464,  464,  500,  618,  618,
      618,  464,  464,  464,  464,  618,  551,  551,  551,  551,
      618,  618,  618,  618,  618,  618,  464,  464,  464,  552,
      464,  552,  618,  618,  618,  618,  618,  618,  618,  618,

      618,  618,  618,  618,  618,  552,  618,  618,  618,  552,
      618,  467,  464,  464,  464,  138,  138,  618,  138,  618,
      618,  618,  138,  138,  138,  138,  138,  138,  618,  618,
      138,  618,  618,  618,  500,  618,  618,  618,  138,  618,
      138,  148,  618,  551,  551,  551,  551,  618,  618,  618,
      618,  618,  618,  138,  618,  138,  552,  618,  552,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      477,  618,  552,  618,  618,  618,  552,  618,  618,  138,
      138,  442,  618,  618,  618,  618,  500,  618,  618,  618,
      503,  503,  503,  503,  618,  501,  501,  501,  501,  618,

      618,  618,  618,  504,  618,  504,  618,  618,  502,  618,
      502,  618,  618,  618,  618,  618,  618,  618,  618,  504,
      505,  618,  618,  504,  502,  505,  618,  618,  502,  508,
      508,  508,  508,  618,  506,  506,  506,  506,  618,  618,
      618,  618,  509,  618,  509,  618,  618,  507,  618,  507,
      618,  618,  618,  618,  618,  618,  618,  618,  509,  505,
      618,  618,  509,  507,  500,  618,  618,  507,  508,  508,
      508,  508,  618,  551,  551,  551,  551,  618,  618,  618,
      618,  509,  618,  509,  618,  618,  552,  618,  552,  618,
      618,  618,  618,  618,  618,  618,  618,  509,  618,  618,

      618,  509,  552,  618,  618,  618,  552,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  618,  618,  618,  618,
      579,  579,  579,  579,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  579,  579,  579,  618,  579,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      580,  579,  579,  579,  582,  582,  582,  582,  582,  582,
      582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
      582,  582,  582,  618,  618,  618,  618,  582,  582,  582,

      582,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  582,  582,  582,  618,  582,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  583,  582,  582,
      582,   26,   26,   26,   26,   26,   26,   26,   26,   26,
       26,   26,   26,   26,   26,   26,   26,   26,   26,   26,
       26,   26,   26,   26,   26,   26,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   42,   42,   42,   42,   42,   42,   42,   42,   42,

       42,   42,   42,   42,   42,   42,   42,   42,   42,   42,
       42,   42,   42,   42,   42,   42,   46,   46,   46,   46,
       46,   46,   46,   46,   46,   46,   46,   46,   46,   46,
       46,   46,   46,   46,   46,   46,   46,   46,   46,   46,
       46,   69,   69,   69,   69,   69,   69,   69,   69,   69,
       69,   69,   69,   69,   69,   69,   69,   69,   69,   69,
       69,   69,   69,   69,   69,   69,   94,   94,   94,   94,
       94,   94,   94,   94,   94,   94,   94,   94,   94,   94,
       94,   94,   94,   94,   94,   94,   94,   94,   94,   94,
       94,   95,   95,   95,   95,   95,   95,   95,   95,   95,

       95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,   95,   95,   95,  103,  618,  618,  618,
      618,  618,  618,  103,  618,  103,  103,  618,  103,  618,
      103,  103,  103,  103,  103,  618,  103,  103,  103,  103,
      103,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  109,  109,  109,  109,
      109,  109,  109,  109,  109,  109,  109,  109,  109,  109,
      109,  109,  109,  109,  109,  109,  109,  109,  109,  109,
      109,  131,  131,  618,  131,  131,  131,  131,  131,  131,

      131,  131,  131,  131,  131,  131,  131,  131,  131,  131,
      131,  131,  131,  131,  131,  131,  132,  132,  618,  132,
      132,  132,  132,  132,  132,  132,  132,  132,  132,  132,
      132,  132,  132,  132,  132,  132,  132,  132,  132,  132,
      132,  138,  138,  618,  618,  618,  618,  138,  138,  138,
      618,  138,  138,  138,  618,  138,  618,  618,  138,  138,
      618,  138,  618,  618,  138,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      139,  139,  139,  139,  139,  139,  139,  139,  139,  139,
      144,  144,  618,  144,  144,  618,  144,  144,  144,  144,

      144,  144,  144,  144,  144,  144,  618,  144,  144,  618,
      144,  144,  618,  144,  144,  147,  147,  618,  618,  618,
      618,  147,  147,  147,  618,  147,  147,  147,  618,  147,
      618,  147,  147,  147,  618,  147,  618,  618,  147,  151,
      151,  151,  618,  151,  618,  618,  151,  151,  618,  151,
      154,  154,  154,  154,  154,  174,  174,  618,  174,  174,
      174,  174,  174,  174,  174,  174,  174,  174,  618,  174,
      174,  618,  174,  174,  618,  174,  186,  186,  186,  186,
      186,  186,  186,  186,  186,  618,  186,  186,  186,  618,
      186,  186,  618,  186,  186,  618,  186,  186,  186,  186,

      186,  189,  189,  189,  189,  189,  189,  189,  189,  189,
      618,  189,  189,  189,  618,  189,  189,  189,  189,  189,
      618,  189,  189,  189,  189,  189,  191,  191,  191,  191,
      191,  191,  191,  191,  191,  618,  191,  191,  191,  618,
      191,  191,  618,  191,  191,  618,  191,  191,  191,  191,
      191,  199,  618,  199,  199,  618,  618,  199,  618,  618,
      618,  199,  199,  618,  199,  618,  618,  199,  199,  618,
      199,  200,  200,  618,  200,  200,  200,  200,  200,  200,
      618,  200,  200,  200,  200,  200,  200,  200,  200,  200,
      618,  200,  200,  618,  618,  200,  205,  205,  205,  205,

      205,  205,  205,  205,  205,  205,  205,  205,  205,  205,
      205,  205,  205,  205,  205,  205,  205,  205,  205,  205,
      205,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  208,  208,  208,  208,  208,  208,  208,  208,  208,
      208,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  211,  211,  211,  211,

      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  211,
      211,  219,  219,  219,  219,  219,  219,  219,  219,  219,
      219,  219,  219,  219,  219,  219,  219,  219,  219,  219,
      219,  219,  219,  219,  219,  219,  246,  618,  618,  246,
      618,  618,  246,  246,  618,  246,  249,  249,  618,  249,
      618,  618,  618,  249,  250,  618,  618,  250,  250,  618,
      250,  618,  250,  174,  174,  618,  174,  174,  174,  174,
      174,  174,  174,  174,  174,  174,  618,  174,  174,  618,
      174,  174,  618,  174,  191,  191,  191,  191,  191,  191,

      191,  191,  191,  618,  191,  191,  191,  618,  191,  191,
      191,  191,  191,  618,  191,  191,  191,  191,  191,  283,
      283,  618,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  283,  283,  283,  283,  283,  283,
      283,  283,  283,  283,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  291,
      291,  291,  291,  291,  291,  291,  291,  291,  291,  294,
      294,  294,  294,  294,  294,  294,  294,  294,  294,  294,
      294,  294,  294,  294,  294,  294,  294,  294,  294,  294,
      294,  294,  294,  294,  305,  618,  618,  618,  618,  618,

      305,  618,  618,  305,  305,  316,  316,  316,  316,  316,
      316,  316,  316,  316,  316,  316,  316,  316,  316,  316,
      316,  316,  316,  316,  316,  316,  316,  316,  316,  316,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
      319,  319,  319,  319,  319,  323,  618,  618,  323,  618,
      618,  323,  323,  618,  323,  151,  151,  151,  618,  151,
      618,  151,  151,  151,  618,  151,  326,  618,  326,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  326,
      618,  618,  326,  326,  618,  326,  250,  618,  618,  250,

      250,  618,  250,  618,  250,  147,  147,  618,  618,  618,
      618,  147,  147,  147,  618,  147,  147,  147,  618,  147,
      618,  147,  147,  147,  618,  147,  618,  618,  147,  351,
      351,  618,  351,  351,  351,  351,  351,  351,  351,  351,
      351,  351,  351,  351,  351,  351,  351,  351,  351,  351,
      351,  351,  351,  351,  359,  359,  359,  359,  359,  359,
      359,  359,  359,  359,  359,  359,  359,  359,  359,  359,
      359,  359,  359,  359,  359,  359,  359,  359,  359,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,

      361,  361,  361,  361,  376,  376,  618,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
      376,  376,  376,  376,  376,  376,  376,  376,  376,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  381,  381,  381,  381,  381,  381,
      381,  381,  381,  381,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  389,
      389,  389,  389,  389,  389,  389,  389,  389,  389,  389,
      389,  389,  389,  389,  389,  389,  389,  389,  389,  389,

      389,  389,  389,  389,  391,  391,  391,  391,  391,  391,
      391,  391,  391,  391,  391,  391,  391,  391,  391,  391,
      391,  391,  391,  391,  391,  391,  391,  391,  391,  393,
      393,  393,  393,  393,  393,  393,  393,  393,  393,  393,
      393,  393,  393,  393,  393,  393,  393,  393,  393,  393,
      393,  393,  393,  393,  395,  618,  618,  395,  618,  618,
      395,  395,  618,  395,  323,  323,  618,  323,  618,  618,
      323,  323,  618,  323,  151,  151,  151,  618,  151,  618,
      151,  151,  151,  618,  151,  326,  618,  326,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  326,  618,

      618,  326,  326,  618,  326,  250,  618,  618,  250,  250,
      618,  250,  618,  250,  147,  147,  618,  618,  618,  618,
      147,  147,  147,  618,  147,  147,  147,  618,  147,  618,
      147,  147,  147,  618,  147,  618,  618,  147,  186,  186,
      186,  186,  186,  186,  186,  186,  186,  618,  186,  186,
      186,  618,  186,  186,  618,  186,  186,  618,  186,  186,
      186,  186,  186,  351,  351,  618,  351,  351,  351,  351,
      351,  351,  351,  351,  351,  351,  351,  351,  351,  351,
      351,  351,  351,  351,  351,  351,  351,  351,  352,  352,
      618,  352,  352,  352,  352,  352,  352,  352,  352,  352,

      352,  352,  352,  352,  352,  352,  352,  352,  352,  352,
      352,  352,  352,  219,  219,  219,  219,  219,  219,  219,
      219,  219,  219,  219,  219,  219,  219,  219,  219,  219,
      219,  219,  219,  219,  219,  219,  219,  219,  359,  359,
      359,  359,  359,  359,  359,  359,  359,  359,  359,  359,
      359,  359,  359,  359,  359,  359,  359,  359,  359,  359,
      359,  359,  359,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  361,  361,
      361,  361,  361,  361,  361,  361,  361,  361,  305,  618,
      305,  305,  618,  618,  305,  618,  618,  305,  305,  445,

      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  445,  445,  445,
      445,  445,  445,  445,  449,  449,  449,  449,  449,  449,
      449,  449,  449,  449,  449,  449,  449,  449,  449,  449,
      449,  449,  449,  449,  449,  449,  449,  449,  449,  454,
      454,  454,  454,  454,  454,  454,  454,  454,  454,  454,
      454,  454,  454,  454,  454,  454,  454,  454,  454,  454,
      454,  454,  454,  454,  456,  456,  456,  456,  456,  456,
      456,  456,  456,  456,  456,  456,  456,  456,  456,  456,
      456,  456,  456,  456,  456,  456,  456,  456,  456,  387,

      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  387,  387,  387,  387,  387,  387,
      387,  387,  387,  387,  389,  389,  389,  389,  389,  389,
      389,  389,  389,  389,  389,  389,  389,  389,  389,  389,
      389,  389,  389,  389,  389,  389,  389,  389,  389,  391,
      391,  391,  391,  391,  391,  391,  391,  391,  391,  391,
      391,  391,  391,  391,  391,  391,  391,  391,  391,  391,
      391,  391,  391,  391,  393,  393,  393,  393,  393,  393,
      393,  393,  393,  393,  393,  393,  393,  393,  393,  393,
      393,  393,  393,  393,  393,  393,  393,  393,  393,  461,

      461,  618,  461,  618,  618,  461,  461,  618,  461,  462,
      618,  618,  462,  618,  618,  462,  462,  618,  462,  151,
      151,  151,  618,  151,  618,  151,  151,  151,  618,  151,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  511,  511,  511,  511,  511,
      511,  511,  511,  511,  511,  513,  513,  513,  513,  513,
      513,  513,  513,  513,  513,  513,  513,  513,  513,  513,
      513,  513,  513,  513,  513,  513,  513,  513,  513,  513,
      515,  515,  618,  515,  618,  618,  515,  515,  618,  515,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,

      541,  541,  541,  618,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  553,  553,  553,  553,  553,
      553,  553,  553,  553,  553,  553,  553,  553,  553,  553,
      553,  553,  553,  553,  553,  553,  553,  553,  553,  553,
      574,  574,  574,  574,  574,  574,  574,  574,  574,  574,
      574,  574,  574,  618,  574,  574,  574,  574,  574,  574,
      574,  574,  574,  574,  574,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  616,  616,  616,  616,
       25,  618,  618,  618,  618,  618,  618,  618,  618,  618,

      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618
    } ;

static const flex_int16_t yy_chk[4459] =
    {   0,
        0,    3,    3,    7,    3,    3,    3,    3,  616,   92,
        3,    7,  615,    3,  179,    3,    3,    3,    3,    3,
        3,    3,    3,   13,   14,   10,   10,  179,   10,    3,
      358,    5,    6,    8,  249,    5,    6,  249,   41,    3,
        7,    8,   10,   13,   14,    3,    4,    4,   38,    4,
        4,    4,    4,   38,   57,    4,   13,   14,    4,   57,
        4,    4,    4,    4,    4,    4,    4,    4,    5,    6,
        8,   41,   68,   92,    4,   37,   37,   37,   37,  166,
       13,   14,   59,  358,    4,   68,  166,   59,   72,   72,
        4,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   12,  144,
      116,   12,   31,   15,  144,   31,   16,   16,  116,   16,
      160,   23,   17,   20,  122,  122,   20,   18,   18,   15,
       18,   91,   23,   16,   31,   31,  612,   15,   17,   50,
      160,   16,   50,  127,   18,   54,   17,  155,   54,   12,

       15,   54,   18,   15,   16,  155,   50,   16,   23,   17,
       54,  127,   17,  164,   20,   18,  248,  145,   18,  128,
      150,   91,  145,   12,   15,  150,   15,   15,   16,  164,
       16,   16,   23,   17,   23,   17,   17,  128,   20,   18,
      248,   18,   18,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,

       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       21,  156,   21,   21,  152,  591,   21,   21,   21,  156,
       21,  157,  159,   21,   21,   21,  185,  159,   21,   64,
      157,  152,   64,   21,   21,   21,   21,   51,  367,  185,
       51,  165,  117,   24,   24,  117,   24,  117,   21,   21,
       21,  165,   21,  204,   51,   24,   65,  162,  117,   65,
       24,   73,  162,  367,   73,   80,  204,  591,   80,  196,
       64,   90,   90,   21,   90,   21,   21,   22,   73,   22,
       22,   24,   80,   22,   22,   22,  137,   22,  137,  261,
       22,   22,   22,  101,   64,   22,  101,   65,  195,  137,

       22,   22,   22,   22,  261,   24,  133,   24,  163,  133,
      101,  158,   90,  163,  158,   22,   22,   22,  118,   22,
      198,   65,  197,  133,  193,  118,  259,  118,  118,  118,
      118,  193,  161,  196,  135,  259,   90,  135,  195,  118,
       22,  158,   22,   22,   35,   35,  161,   35,   35,   35,
       35,  135,  161,   35,  140,  118,  463,  140,   35,   35,
      140,   35,  197,  121,  121,  121,  158,   35,   35,  140,
      229,  491,  121,  222,  119,  119,  119,  119,  222,  229,
      229,  121,   35,   39,  198,  463,  119,  119,  121,  119,
       39,  238,   39,   39,   39,   39,  177,  168,  239,  177,

      168,   39,  119,  119,   39,  121,  491,  119,  260,  238,
       39,  169,  120,  177,  169,  183,  239,   39,  183,  120,
       39,  120,  120,  120,  120,  176,  260,  325,  324,  176,
      325,  254,  183,  120,   39,   40,  202,  253,  168,  202,
      194,  194,   40,  194,   40,   40,   40,   40,  254,  120,
      253,  223,  169,  202,  324,  253,   40,  176,  123,   40,
      123,   40,  168,  123,  123,  123,  123,  223,  230,  230,
      230,  230,   40,  244,  258,  519,  169,   40,  241,  258,
      241,  194,  176,  263,   40,   58,   58,  519,   58,  244,
      263,  241,   58,   58,   58,   58,   58,   58,  262,  280,

       58,  231,  231,  231,  231,  194,  257,  215,   58,  215,
       58,   58,  215,  215,  215,  215,  257,  225,  262,  224,
      224,  224,  224,   58,  225,   58,  225,  225,  225,  225,
      278,  224,  224,  264,  224,  226,  397,  226,  225,  278,
      226,  226,  226,  226,  264,  296,  227,  224,  224,   58,
       58,   61,  224,  227,  225,  227,  227,  227,  227,  277,
      279,  296,  326,  280,   61,  326,  277,  227,  397,  332,
       61,   61,   61,   61,   61,  293,  252,   61,   61,  281,
      332,   61,   61,  227,  252,   61,   61,   62,   62,  292,
       62,  331,  292,  252,   62,   62,   62,   62,   62,   62,

      279,  610,   62,  293,  336,  281,  292,  228,  321,  331,
       62,  336,   62,   62,  228,  608,  228,  228,  228,  228,
      287,  287,  287,  287,  321,   62,  301,   62,  228,  281,
       62,  281,  285,  302,  285,  301,  301,  285,  285,  285,
      285,  334,  302,  302,  228,  288,  288,  288,  288,  334,
      327,   62,   62,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,  327,  335,   85,  328,
      295,  295,  232,  295,  333,  335,   85,   85,   85,   85,
      607,  232,  232,  232,  232,  364,  328,  295,  329,  337,
      333,   85,  338,   85,  232,   85,  232,  311,  349,  311,

      338,  364,  311,  311,  311,  311,  350,  329,  337,  379,
      232,  404,  424,  404,  232,  424,   85,   85,   85,   85,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,  356,  423,   87,  356,  289,  349,  360,
      423,  384,  360,   87,   87,   87,  289,  289,  289,  289,
      356,  520,  362,  362,  298,  362,  360,  384,   87,  289,
       87,  289,   87,  298,  298,  298,  298,  605,  520,  362,
      350,  366,  379,   87,  313,  289,  298,  313,  298,  289,
      366,  366,  399,   87,   87,   87,   87,   88,  343,  351,
      399,  343,  298,  386,  343,  343,  298,  313,  343,  313,

       88,  474,  343,  343,  604,  474,   88,   88,   88,   88,
       88,  402,  313,   88,   88,  351,  448,   88,   88,  402,
      408,   88,   88,   89,   89,   89,   89,   89,   89,   89,
       89,   89,   89,   89,   89,   89,  403,  452,   89,  351,
      408,  351,  363,  299,  403,  363,   89,   89,   89,   89,
      299,  546,  299,  299,  299,  299,  386,  407,  427,  363,
      300,   89,  407,   89,  299,   89,   89,  300,  405,  300,
      300,  300,  300,  373,  373,  373,  373,  405,  475,  448,
      299,  300,  603,  475,  344,  344,   89,   89,   89,   89,
      109,  109,  344,  109,  109,  109,  109,  300,  344,  109,

      452,  427,  546,  303,  109,  109,  426,  109,  374,  374,
      374,  374,  303,  303,  303,  303,  369,  406,  369,  426,
      602,  369,  369,  369,  369,  303,  406,  303,  109,  113,
      113,  409,  113,  113,  113,  113,  428,  433,  113,  428,
      409,  303,  599,  113,  113,  303,  113,  315,  315,  304,
      315,  438,  430,  428,  490,  430,  495,  490,  304,  304,
      304,  304,  433,  459,  315,  426,  468,  113,  115,  430,
      315,  304,  315,  304,  468,  472,  438,  115,  115,  115,
      115,  435,  435,  435,  435,  315,  472,  304,  432,  115,
      115,  304,  115,  434,  469,  434,  473,  476,  434,  434,

      434,  434,  598,  469,  432,  115,  115,  473,  476,  516,
      115,  124,  516,  495,  124,  436,  436,  436,  436,  124,
      124,  124,  124,  124,  124,  124,  459,  614,  124,  597,
      124,  124,  124,  124,  124,  124,  124,  124,  124,  124,
      124,  124,  124,  124,  124,  124,  124,  124,  124,  124,
      432,  124,  124,  124,  124,  124,  124,  124,  124,  124,
      124,  124,  124,  124,  124,  124,  124,  124,  124,  124,
      124,  124,  124,  124,  124,  124,  124,  124,  125,  614,
      477,  377,  377,  353,  377,  125,  525,  125,  125,  125,
      125,  470,  353,  353,  353,  353,  525,  504,  596,  125,

      470,  504,  125,  504,  125,  353,  377,  353,  465,  465,
      465,  465,  477,  478,  478,  125,  478,  497,  521,  377,
      125,  353,  354,  378,  378,  353,  378,  125,  126,  521,
      497,  354,  354,  354,  354,  126,  522,  126,  126,  126,
      126,  595,  471,  528,  354,  522,  354,  372,  378,  126,
      471,  372,  126,  372,  126,  496,  372,  372,  372,  372,
      354,  378,  526,  515,  354,  126,  523,  523,  496,  550,
      126,  515,  528,  382,  382,  526,  382,  126,  191,  191,
      191,  191,  191,  191,  191,  191,  191,  191,  191,  191,
      191,  594,  493,  191,  540,  493,  593,  355,  382,  524,

      524,  191,  191,  191,  191,  539,  355,  355,  355,  355,
      600,  382,  527,  527,  496,  590,  191,  493,  191,  355,
      191,  355,  517,  517,  517,  517,  540,  589,  557,  613,
      493,  588,  550,  573,  539,  355,  557,  385,  385,  355,
      385,  191,  191,  191,  191,  192,  192,  192,  192,  192,
      192,  192,  192,  192,  192,  192,  192,  192,  559,  559,
      192,  560,  385,  562,  447,  447,  600,  447,  192,  192,
      192,  192,  560,  571,  562,  385,  450,  450,  573,  450,
      609,  365,  613,  192,  563,  192,  587,  192,  192,  447,
      365,  365,  365,  365,  563,  458,  458,  494,  458,  571,

      494,  450,  447,  365,  606,  365,  581,  581,  192,  192,
      192,  192,  210,  210,  450,  210,  210,  210,  210,  365,
      458,  210,  494,  365,  586,  578,  210,  210,  592,  210,
      601,  601,  375,  458,  578,  494,  609,  687,  585,  592,
      687,  375,  375,  375,  375,  606,  498,  498,  611,  498,
      210,  213,  542,  584,  375,  542,  375,  425,  577,  576,
      213,  213,  213,  213,  570,  569,  425,  425,  425,  425,
      375,  498,  213,  213,  375,  213,  568,  542,  567,  425,
      566,  425,  544,  548,  498,  544,  548,  565,  213,  213,
      542,  564,  556,  213,  214,  425,  611,  549,  549,  425,

      549,  553,  545,  214,  214,  214,  214,  544,  548,  543,
      537,  536,  535,  534,  533,  214,  214,  686,  214,  532,
      544,  548,  549,  686,  531,  530,  686,  513,  511,  510,
      575,  214,  214,  575,  489,  549,  214,  234,  234,  234,
      234,  488,  487,  486,  485,  234,  234,  234,  234,  234,
      234,  484,  483,  482,  481,  575,  480,  479,  462,  461,
      460,  234,  234,  234,  234,  234,  234,  235,  575,  456,
      235,  454,  453,  449,  445,  235,  235,  235,  235,  235,
      235,  235,  431,  429,  235,  422,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,

      235,  235,  235,  235,  235,  235,  421,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  235,
      235,  235,  235,  235,  236,  420,  419,  418,  417,  416,
      415,  236,  414,  236,  236,  236,  236,  413,  412,  411,
      395,  236,  236,  236,  236,  236,  236,  393,  391,  236,
      389,  387,  381,  380,  376,  437,  370,  236,  236,  236,
      236,  236,  236,  237,  437,  437,  437,  437,  361,  359,
      237,  357,  237,  237,  237,  237,  346,  437,  345,  437,
      342,  341,  340,  323,  237,  319,  318,  237,  317,  237,

      316,  314,  308,  437,  305,  294,  291,  437,  274,  273,
      237,  272,  269,  268,  267,  237,  266,  250,  246,  243,
      242,  233,  237,  265,  265,  221,  265,  219,  218,  208,
      265,  265,  265,  265,  265,  265,  207,  205,  265,  203,
      190,  189,  440,  186,  184,  182,  265,  181,  265,  265,
      180,  440,  440,  440,  440,  178,  175,  173,  172,  171,
      170,  265,  167,  265,  440,  154,  440,  151,  147,  143,
      136,  134,  114,  112,  110,  265,  107,  106,  104,  102,
      440,   97,   86,   84,  440,   82,   81,  265,  265,  306,
       79,   76,   75,   74,   67,   66,   63,   60,  306,  306,

      306,  306,   56,   52,   36,   33,  306,  306,  306,  306,
      306,  306,   32,   25,  306,    9,    2,    1,    0,    0,
        0,    0,  306,  306,  306,  306,  306,  306,  307,    0,
        0,    0,    0,    0,    0,  307,    0,  307,  307,  307,
      307,    0,    0,    0,    0,  307,  307,  307,  307,  307,
      307,  307,  307,  307,  307,  307,    0,    0,    0,    0,
        0,  307,  307,  307,  307,  307,  307,  307,  307,  307,
      307,  307,  307,  307,  307,  307,  307,  307,  307,  307,
      307,  330,  330,  330,  330,  330,  330,  330,  330,  330,
      330,  330,  330,  330,  330,  330,  330,  330,  330,  330,

      441,    0,    0,    0,  330,  330,  330,  330,    0,  441,
      441,  441,  441,    0,    0,    0,    0,    0,    0,  330,
      330,  330,  441,  330,  441,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  441,    0,
        0,    0,  441,    0,  330,  330,  330,  330,  339,  339,
        0,  339,    0,    0,    0,  339,  339,  339,  339,  339,
      339,    0,    0,  339,    0,    0,    0,  443,    0,    0,
        0,  339,    0,  339,  339,    0,  443,  443,  443,  443,
        0,    0,    0,    0,    0,    0,  339,    0,  339,  443,
        0,  443,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,  443,  339,    0,    0,  443,
        0,    0,  339,  339,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,    0,  347,  347,
      347,  347,    0,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,    0,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  347,
      347,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,    0,  348,  348,  348,  348,    0,

      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
        0,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  348,  348,
      348,  348,  348,  348,  348,  348,  348,  348,  398,  398,
      398,  398,  398,  398,  398,  398,  398,  398,  398,  398,
      398,  398,  398,  398,  398,  398,  398,  499,    0,    0,
        0,  398,  398,  398,  398,    0,  499,  499,  499,  499,
        0,    0,    0,    0,    0,    0,  398,  398,  398,  499,
      398,  499,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,  499,    0,    0,    0,  499,
        0,  398,  398,  398,  398,  410,  410,    0,  410,    0,
        0,    0,  410,  410,  410,  410,  410,  410,    0,    0,
      410,    0,    0,    0,  500,    0,    0,    0,  410,    0,
      410,  410,    0,  500,  500,  500,  500,    0,    0,    0,
        0,    0,    0,  410,    0,  410,  500,    0,  500,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      410,    0,  500,    0,    0,    0,  500,    0,    0,  410,
      410,  439,    0,    0,    0,  439,  501,  439,    0,    0,
      439,  439,  439,  439,    0,  501,  501,  501,  501,    0,

        0,    0,    0,  439,    0,  439,    0,    0,  501,    0,
      501,    0,    0,    0,    0,    0,    0,    0,    0,  439,
      505,    0,    0,  439,  501,  506,    0,    0,  501,  505,
      505,  505,  505,    0,  506,  506,  506,  506,    0,    0,
        0,    0,  505,    0,  505,    0,    0,  506,    0,  506,
        0,    0,    0,    0,    0,    0,    0,    0,  505,  508,
        0,    0,  505,  506,  551,    0,    0,  506,  508,  508,
      508,  508,    0,  551,  551,  551,  551,    0,    0,    0,
        0,  508,    0,  508,    0,    0,  551,    0,  551,    0,
        0,    0,    0,    0,    0,    0,    0,  508,    0,    0,

        0,  508,  551,    0,    0,    0,  551,  558,  558,  558,
      558,  558,  558,  558,  558,  558,  558,  558,  558,  558,
      558,  558,  558,  558,  558,  558,    0,    0,    0,    0,
      558,  558,  558,  558,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  558,  558,  558,    0,  558,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      558,  558,  558,  558,  561,  561,  561,  561,  561,  561,
      561,  561,  561,  561,  561,  561,  561,  561,  561,  561,
      561,  561,  561,    0,    0,    0,    0,  561,  561,  561,

      561,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  561,  561,  561,    0,  561,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  561,  561,  561,
      561,  619,  619,  619,  619,  619,  619,  619,  619,  619,
      619,  619,  619,  619,  619,  619,  619,  619,  619,  619,
      619,  619,  619,  619,  619,  619,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  621,  621,  621,  621,  621,  621,  621,  621,  621,

      621,  621,  621,  621,  621,  621,  621,  621,  621,  621,
      621,  621,  621,  621,  621,  621,  622,  622,  622,  622,
      622,  622,  622,  622,  622,  622,  622,  622,  622,  622,
      622,  622,  622,  622,  622,  622,  622,  622,  622,  622,
      622,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  623,  623,  623,  623,
      623,  623,  623,  623,  623,  623,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  624,  624,  624,  624,  624,  624,  624,  624,  624,
      624,  625,  625,  625,  625,  625,  625,  625,  625,  625,

      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  626,    0,    0,    0,
        0,    0,    0,  626,    0,  626,  626,    0,  626,    0,
      626,  626,  626,  626,  626,    0,  626,  626,  626,  626,
      626,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  627,  627,  627,  627,
      627,  627,  627,  627,  627,  627,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  628,  628,  628,  628,  628,  628,  628,  628,  628,
      628,  629,  629,    0,  629,  629,  629,  629,  629,  629,

      629,  629,  629,  629,  629,  629,  629,  629,  629,  629,
      629,  629,  629,  629,  629,  629,  630,  630,    0,  630,
      630,  630,  630,  630,  630,  630,  630,  630,  630,  630,
      630,  630,  630,  630,  630,  630,  630,  630,  630,  630,
      630,  631,  631,    0,    0,    0,    0,  631,  631,  631,
        0,  631,  631,  631,    0,  631,    0,    0,  631,  631,
        0,  631,    0,    0,  631,  632,  632,  632,  632,  632,
      632,  632,  632,  632,  632,  632,  632,  632,  632,  632,
      632,  632,  632,  632,  632,  632,  632,  632,  632,  632,
      633,  633,    0,  633,  633,    0,  633,  633,  633,  633,

      633,  633,  633,  633,  633,  633,    0,  633,  633,    0,
      633,  633,    0,  633,  633,  634,  634,    0,    0,    0,
        0,  634,  634,  634,    0,  634,  634,  634,    0,  634,
        0,  634,  634,  634,    0,  634,    0,    0,  634,  635,
      635,  635,    0,  635,    0,    0,  635,  635,    0,  635,
      636,  636,  636,  636,  636,  637,  637,    0,  637,  637,
      637,  637,  637,  637,  637,  637,  637,  637,    0,  637,
      637,    0,  637,  637,    0,  637,  638,  638,  638,  638,
      638,  638,  638,  638,  638,    0,  638,  638,  638,    0,
      638,  638,    0,  638,  638,    0,  638,  638,  638,  638,

      638,  639,  639,  639,  639,  639,  639,  639,  639,  639,
        0,  639,  639,  639,    0,  639,  639,  639,  639,  639,
        0,  639,  639,  639,  639,  639,  640,  640,  640,  640,
      640,  640,  640,  640,  640,    0,  640,  640,  640,    0,
      640,  640,    0,  640,  640,    0,  640,  640,  640,  640,
      640,  641,    0,  641,  641,    0,    0,  641,    0,    0,
        0,  641,  641,    0,  641,    0,    0,  641,  641,    0,
      641,  642,  642,    0,  642,  642,  642,  642,  642,  642,
        0,  642,  642,  642,  642,  642,  642,  642,  642,  642,
        0,  642,  642,    0,    0,  642,  643,  643,  643,  643,

      643,  643,  643,  643,  643,  643,  643,  643,  643,  643,
      643,  643,  643,  643,  643,  643,  643,  643,  643,  643,
      643,  644,  644,  644,  644,  644,  644,  644,  644,  644,
      644,  644,  644,  644,  644,  644,  644,  644,  644,  644,
      644,  644,  644,  644,  644,  644,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  646,  646,  646,  646,  646,  646,  646,  646,  646,
      646,  646,  646,  646,  646,  646,  646,  646,  646,  646,
      646,  646,  646,  646,  646,  646,  647,  647,  647,  647,

      647,  647,  647,  647,  647,  647,  647,  647,  647,  647,
      647,  647,  647,  647,  647,  647,  647,  647,  647,  647,
      647,  648,  648,  648,  648,  648,  648,  648,  648,  648,
      648,  648,  648,  648,  648,  648,  648,  648,  648,  648,
      648,  648,  648,  648,  648,  648,  649,    0,    0,  649,
        0,    0,  649,  649,    0,  649,  650,  650,    0,  650,
        0,    0,    0,  650,  651,    0,    0,  651,  651,    0,
      651,    0,  651,  652,  652,    0,  652,  652,  652,  652,
      652,  652,  652,  652,  652,  652,    0,  652,  652,    0,
      652,  652,    0,  652,  653,  653,  653,  653,  653,  653,

      653,  653,  653,    0,  653,  653,  653,    0,  653,  653,
      653,  653,  653,    0,  653,  653,  653,  653,  653,  654,
      654,    0,  654,  654,  654,  654,  654,  654,  654,  654,
      654,  654,  654,  654,  654,  654,  654,  654,  654,  654,
      654,  654,  654,  654,  655,  655,  655,  655,  655,  655,
      655,  655,  655,  655,  655,  655,  655,  655,  655,  655,
      655,  655,  655,  655,  655,  655,  655,  655,  655,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  656,  656,  656,  656,  656,  656,
      656,  656,  656,  656,  657,    0,    0,    0,    0,    0,

      657,    0,    0,  657,  657,  658,  658,  658,  658,  658,
      658,  658,  658,  658,  658,  658,  658,  658,  658,  658,
      658,  658,  658,  658,  658,  658,  658,  658,  658,  658,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  659,  659,  659,  659,  659,
      659,  659,  659,  659,  659,  660,    0,    0,  660,    0,
        0,  660,  660,    0,  660,  661,  661,  661,    0,  661,
        0,  661,  661,  661,    0,  661,  662,    0,  662,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  662,
        0,    0,  662,  662,    0,  662,  663,    0,    0,  663,

      663,    0,  663,    0,  663,  664,  664,    0,    0,    0,
        0,  664,  664,  664,    0,  664,  664,  664,    0,  664,
        0,  664,  664,  664,    0,  664,    0,    0,  664,  665,
      665,    0,  665,  665,  665,  665,  665,  665,  665,  665,
      665,  665,  665,  665,  665,  665,  665,  665,  665,  665,
      665,  665,  665,  665,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  666,  666,  666,  666,  666,  666,  667,
      667,  667,  667,  667,  667,  667,  667,  667,  667,  667,
      667,  667,  667,  667,  667,  667,  667,  667,  667,  667,

      667,  667,  667,  667,  668,  668,    0,  668,  668,  668,
      668,  668,  668,  668,  668,  668,  668,  668,  668,  668,
      668,  668,  668,  668,  668,  668,  668,  668,  668,  669,
      669,  669,  669,  669,  669,  669,  669,  669,  669,  669,
      669,  669,  669,  669,  669,  669,  669,  669,  669,  669,
      669,  669,  669,  669,  670,  670,  670,  670,  670,  670,
      670,  670,  670,  670,  670,  670,  670,  670,  670,  670,
      670,  670,  670,  670,  670,  670,  670,  670,  670,  671,
      671,  671,  671,  671,  671,  671,  671,  671,  671,  671,
      671,  671,  671,  671,  671,  671,  671,  671,  671,  671,

      671,  671,  671,  671,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  672,  672,  673,
      673,  673,  673,  673,  673,  673,  673,  673,  673,  673,
      673,  673,  673,  673,  673,  673,  673,  673,  673,  673,
      673,  673,  673,  673,  674,    0,    0,  674,    0,    0,
      674,  674,    0,  674,  675,  675,    0,  675,    0,    0,
      675,  675,    0,  675,  676,  676,  676,    0,  676,    0,
      676,  676,  676,    0,  676,  677,    0,  677,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  677,    0,

        0,  677,  677,    0,  677,  678,    0,    0,  678,  678,
        0,  678,    0,  678,  679,  679,    0,    0,    0,    0,
      679,  679,  679,    0,  679,  679,  679,    0,  679,    0,
      679,  679,  679,    0,  679,    0,    0,  679,  680,  680,
      680,  680,  680,  680,  680,  680,  680,    0,  680,  680,
      680,    0,  680,  680,    0,  680,  680,    0,  680,  680,
      680,  680,  680,  681,  681,    0,  681,  681,  681,  681,
      681,  681,  681,  681,  681,  681,  681,  681,  681,  681,
      681,  681,  681,  681,  681,  681,  681,  681,  682,  682,
        0,  682,  682,  682,  682,  682,  682,  682,  682,  682,

      682,  682,  682,  682,  682,  682,  682,  682,  682,  682,
      682,  682,  682,  683,  683,  683,  683,  683,  683,  683,
      683,  683,  683,  683,  683,  683,  683,  683,  683,  683,
      683,  683,  683,  683,  683,  683,  683,  683,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  684,  684,  684,  684,  684,  684,  684,
      684,  684,  684,  685,  685,  685,  685,  685,  685,  685,
      685,  685,  685,  685,  685,  685,  685,  685,  685,  685,
      685,  685,  685,  685,  685,  685,  685,  685,  688,    0,
      688,  688,    0,    0,  688,    0,    0,  688,  688,  689,

      689,  689,  689,  689,  689,  689,  689,  689,  689,  689,
      689,  689,  689,  689,  689,  689,  689,  689,  689,  689,
      689,  689,  689,  689,  690,  690,  690,  690,  690,  690,
      690,  690,  690,  690,  690,  690,  690,  690,  690,  690,
      690,  690,  690,  690,  690,  690,  690,  690,  690,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  691,  691,  691,  691,  691,  691,
      691,  691,  691,  691,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  692,
      692,  692,  692,  692,  692,  692,  692,  692,  692,  693,

      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  693,  693,  693,  693,  693,  693,
      693,  693,  693,  693,  694,  694,  694,  694,  694,  694,
      694,  694,  694,  694,  694,  694,  694,  694,  694,  694,
      694,  694,  694,  694,  694,  694,  694,  694,  694,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  695,  695,  695,  695,  695,  695,
      695,  695,  695,  695,  696,  696,  696,  696,  696,  696,
      696,  696,  696,  696,  696,  696,  696,  696,  696,  696,
      696,  696,  696,  696,  696,  696,  696,  696,  696,  697,

      697,    0,  697,    0,    0,  697,  697,    0,  697,  698,
        0,    0,  698,    0,    0,  698,  698,    0,  698,  699,
      699,  699,    0,  699,    0,  699,  699,  699,    0,  699,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  700,  700,  700,  700,  700,
      700,  700,  700,  700,  700,  701,  701,  701,  701,  701,
      701,  701,  701,  701,  701,  701,  701,  701,  701,  701,
      701,  701,  701,  701,  701,  701,  701,  701,  701,  701,
      702,  702,    0,  702,    0,    0,  702,  702,    0,  702,
      703,  703,  703,  703,  703,  703,  703,  703,  703,  703,

      703,  703,  703,    0,  703,  703,  703,  703,  703,  703,
      703,  703,  703,  703,  703,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      704,  704,  704,  704,  704,  704,  704,  704,  704,  704,
      705,  705,  705,  705,  705,  705,  705,  705,  705,  705,
      705,  705,  705,    0,  705,  705,  705,  705,  705,  705,
      705,  705,  705,  705,  705,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      706,  706,  706,  706,  706,  706,  706,  706,  706,  706,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,

      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618,  618,  618,
      618,  618,  618,  618,  618,  618,  618,  618
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
/*****************************************************************************
 *
 * 
 *
 * Copyright (C) 1997-2015 by Dimitri van Heesch.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation under the terms of the GNU General Public License is hereby 
 * granted. No representations are made about the suitability of this software 
 * for any purpose. It is provided "as is" without express or implied warranty.
 * See the GNU General Public License for more details.
 *
 * Documents produced by Doxygen are derivative works derived from the
 * input used in their production; they are not affected by this license.
 *
 */

#line 26 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"

  
#include <stdio.h>
#include <stdlib.h>
#include <stack>
#include <algorithm>

#include "bufstr.h"
#include "debug.h"
#include "message.h"
#include "config.h"
#include "doxygen.h"
#include "util.h"
#include "condparser.h"

#include <assert.h>

#define YY_NO_INPUT 1
#define YY_NO_UNISTD_H 1

#define ADDCHAR(c)    yyextra->outBuf->addChar(c)
#define ADDARRAY(a,s) yyextra->outBuf->addArray(a,s)

#define USE_STATE2STRING 0
  
struct CondCtx
{
  CondCtx(int line,QCString id,bool b) 
    : lineNr(line),sectionId(id), skip(b) {}
  int lineNr;
  QCString sectionId;
  bool skip;
};
  
struct CommentCtx
{
  CommentCtx(int line) 
    : lineNr(line) {}
  int lineNr;
};
  
struct commentcnvYY_state
{
  BufStr * inBuf = 0;
  BufStr * outBuf = 0;
  yy_size_t inBufPos = 0;
  int      col = 0;
  int      blockHeadCol = 0;
  bool     mlBrief = FALSE;
  int      readLineCtx = 0;
  bool     skip = FALSE;
  QCString fileName;
  int      lineNr = 0;
  int      condCtx = 0;
  std::stack<CondCtx> condStack;
  std::stack<int> commentStack;
  QCString blockName;
  int      lastCommentContext = 0;
  bool     inSpecialComment = FALSE;
  bool     inRoseComment= FALSE;
  int      stringContext = 0;
  int      charContext = 0;
  int      javaBlock = 0;
  bool     specialComment = FALSE;

  QCString aliasString;
  int      blockCount = 0;
  bool     lastEscaped = FALSE;
  int      lastBlockContext= 0;
  bool     pythonDocString = FALSE;
  int      nestingCount= 0;

  bool     vhdl = FALSE; // for VHDL old style --! comment

  SrcLangExt lang = SrcLangExt_Unknown;
  bool       isFixedForm = FALSE; // For Fortran
};

#if USE_STATE2STRING
static const char *stateToString(int state);
#endif
static inline int computeIndent(const char *s);

static void replaceCommentMarker(yyscan_t yyscanner,const char *s,int len);
static inline void copyToOutput(yyscan_t yyscanner,const char *s,int len);
static void startCondSection(yyscan_t yyscanner,const QCString &sectId);
static void endCondSection(yyscan_t yyscanner);
static void handleCondSectionId(yyscan_t yyscanner,const char *expression);
static void replaceAliases(yyscan_t yyscanner,const QCString &s);
static yy_size_t yyread(yyscan_t yyscanner,char *buf,yy_size_t max_size);
static void replaceComment(yyscan_t yyscanner,int offset);
static void clearCommentStack(yyscan_t yyscanner);




#undef  YY_INPUT
#define YY_INPUT(buf,result,max_size) result=yyread(yyscanner,buf,max_size);


#line 2037 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/commentcnv.cpp"

#line 145 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
  //- start: NUMBER -------------------------------------------------------------------------
  // Note same defines in code.l: keep in sync
  //- end: NUMBER ---------------------------------------------------------------------------
  // C start comment 
  // C end comment
  // Cpp comment 
  // Optional any character
  // Optional white space
  // readline non special
  // Optional slash
#line 2050 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/commentcnv.cpp"

#define INITIAL 0
#define Scan 1
#define SkipString 2
#define SkipChar 3
#define SComment 4
#define CComment 5
#define CNComment 6
#define Verbatim 7
#define VerbatimCode 8
#define ReadLine 9
#define CondLine 10
#define ReadAliasArgs 11

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct commentcnvYY_state *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 190 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"


#line 2342 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/commentcnv.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 619 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 618 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 192 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ //Note similar code in code.l
                                      if (yyextra->lang!=SrcLangExt_Cpp) REJECT;
                                      copyToOutput(yyscanner,yytext,(int)yyleng); 
                                    }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 196 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* eat anything that is not " / , or \n */
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
                                    }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 199 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* eat , so we have a nice separator in long initialization lines */ 
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
                                    }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 202 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* start of python long comment */
                                     if (yyextra->lang!=SrcLangExt_Python)
				     {
				       REJECT;
				     }
				     else
				     {
                                       yyextra->pythonDocString = TRUE;
                                       yyextra->nestingCount=1;
                                       clearCommentStack(yyscanner); /*  to be on the save side */
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
                                   }
	YY_BREAK
case 5:
/* rule 5 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 2);
yyg->yy_c_buf_p = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 217 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
                                       yyextra->nestingCount=0; // Fortran doesn't have an end comment
                                       clearCommentStack(yyscanner); /*  to be on the save side */
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
  				   }
	YY_BREAK
case 6:
/* rule 6 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 2);
yyg->yy_c_buf_p = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 231 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       /* check for fixed format; we might have some conditional as part of multiline if like C<5 .and. & */
                                       if (yyextra->isFixedForm && (yyextra->col == 0))
                                       {
                                         copyToOutput(yyscanner,yytext,(int)yyleng); 
                                         yyextra->nestingCount=0; // Fortran doesn't have an end comment
                                         clearCommentStack(yyscanner); /*  to be on the save side */
				         BEGIN(CComment);
                                         yyextra->commentStack.push(yyextra->lineNr);
				       }
				       else
				       {
				         REJECT;
				       }
				     }
  				   }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 253 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
  			             if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
				     }
                                   }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 263 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
  			             if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       if (yyextra->col == 0)
                                       {
                                         copyToOutput(yyscanner,yytext,(int)yyleng); 
				       }
				       else
				       {
				         REJECT;
				       }
				     }
                                   }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 280 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* start of a string */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->stringContext = YY_START;
				     BEGIN(SkipString); 
                                   }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 285 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->charContext = YY_START;
                                     if (yyextra->lang!=SrcLangExt_VHDL)
                                     {
				       BEGIN(SkipChar);
                                     }
  				   }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 293 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* new line */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 12:
/* rule 12 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 3);
yyg->yy_c_buf_p = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
#line 297 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 297 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* start C++ style special comment block */
  				     if (yyextra->mlBrief) 
				     {
				       REJECT; // bail out if we do not need to convert
				     }
				     else
				     {
				       int i=3;
				       if (yytext[2]=='/')
				       {
					 while (i<(int)yyleng && yytext[i]=='/') i++;
				       }
				       yyextra->blockHeadCol=yyextra->col;
				       copyToOutput(yyscanner,"/**",3); 
				       replaceAliases(yyscanner,QCString(yytext+i));
				       yyextra->inSpecialComment=TRUE;
				       //BEGIN(SComment); 
				       yyextra->readLineCtx=SComment;
				       BEGIN(ReadLine);
				     }
                                   }
	YY_BREAK
case 14:
/* rule 14 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 318 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* Start of Rational Rose ANSI C++ comment block */
                                     if (yyextra->mlBrief) REJECT;
                                     int i=17; //=strlen("//##Documentation");
				     yyextra->blockHeadCol=yyextra->col;
				     copyToOutput(yyscanner,"/**",3);
				     replaceAliases(yyscanner,QCString(yytext+i));
				     yyextra->inRoseComment=TRUE;
				     BEGIN(SComment);
  				   }
	YY_BREAK
case 15:
/* rule 15 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 3);
yyg->yy_c_buf_p = yy_cp = yy_bp + 3;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 327 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // next line contains an end marker, see bug 752712
				     yyextra->inSpecialComment=yytext[2]=='/' || yytext[2]=='!';
  				     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
                                   }
	YY_BREAK
case 16:
/* rule 16 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 2);
yyg->yy_c_buf_p = yy_cp = yy_bp + 2;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 333 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* one line C++ comment */ 
				     yyextra->inSpecialComment=yytext[2]=='/' || yytext[2]=='!';
  				     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
				   }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 339 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* avoid matching next rule for empty C comment, see bug 711723 */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 342 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* start of a C comment */
                                     if (yyextra->lang==SrcLangExt_Python)
				     {
				       REJECT;
                                     }
  			             yyextra->specialComment=(int)yyleng==3;
                                     yyextra->nestingCount=1;
                                     clearCommentStack(yyscanner); /*  to be on the save side */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                     if (yyextra->specialComment)
				       BEGIN(CComment); 
                                     else
				       BEGIN(CNComment); 
                                     yyextra->commentStack.push(yyextra->lineNr);
                                   }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 357 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lang!=SrcLangExt_Python)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
                                       yyextra->nestingCount=0; // Python doesn't have an end comment for #
                                       clearCommentStack(yyscanner); /*  to be on the save side */
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
  				   }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 371 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lang!=SrcLangExt_VHDL)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
				     }
  				   }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 381 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lang!=SrcLangExt_VHDL)
				     {
				       REJECT;
				     }
				     else
				     {
                                       yyextra->vhdl = TRUE;
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
                                       yyextra->nestingCount=0;  // VHDL doesn't have an end comment
                                       clearCommentStack(yyscanner); /*  to be on the save side */
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
  				   }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 396 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lang!=SrcLangExt_Fortran)
				     {
				       REJECT;
				     }
				     else
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
                                       yyextra->nestingCount=0;  // Fortran doesn't have an end comment
                                       clearCommentStack(yyscanner); /*  to be on the save side */
				       BEGIN(CComment);
                                       yyextra->commentStack.push(yyextra->lineNr);
				     }
  				   }
	YY_BREAK
case 23:
#line 411 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
case 24:
YY_RULE_SETUP
#line 411 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // Mail address, to prevent seeing e.g x@code-factory.org as start of a code block
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 25:
/* rule 25 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 6);
yyg->yy_c_buf_p = yy_cp = yy_bp + 6;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 414 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     copyToOutput(yyscanner,"@code",5); 
				     yyextra->lastCommentContext = YY_START;
				     yyextra->javaBlock=1;
				     yyextra->blockName=&yytext[1];
                                     BEGIN(VerbatimCode);
  				   }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 421 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* start of markdown code block */
                                     if (!Config_getBool(MARKDOWN_SUPPORT))
                                     {
                                       REJECT;
                                     }
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                     yyextra->lastCommentContext = YY_START;
                                     yyextra->javaBlock=0;
                                     yyextra->blockName=QCString(yytext).stripWhiteSpace().left(3);
                                     BEGIN(VerbatimCode);
                                   }
	YY_BREAK
case 27:
/* rule 27 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 432 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* start of a verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->lastCommentContext = YY_START;
				     yyextra->javaBlock=0;
                                     if (qstrcmp(&yytext[1],"startuml")==0)
                                     {
                                       yyextra->blockName="uml";
                                     }
                                     else
                                     {
				       yyextra->blockName=&yytext[1];
                                     }
                                     BEGIN(VerbatimCode);
  				   }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 446 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->blockName=&yytext[1];
				     if (yyextra->blockName.at(1)=='[')
				     {
				       yyextra->blockName.at(1)=']';
				     }
				     else if (yyextra->blockName.at(1)=='{')
				     {
				       yyextra->blockName.at(1)='}';
				     }
				     else if (yyextra->blockName.at(1)=='(')
				     {
				       yyextra->blockName.at(1)=')';
				     }
				     yyextra->lastCommentContext = YY_START;
				     BEGIN(Verbatim);
  			           }
	YY_BREAK
case 29:
/* rule 29 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 464 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* start of a verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->blockName=&yytext[1];
				     yyextra->lastCommentContext = YY_START;
                                     BEGIN(Verbatim);
                                   }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 470 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* escaped double quote */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 473 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* escaped backslash */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 476 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* any other character */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 479 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* end of verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
				     if (&yytext[1]==yyextra->blockName) // end of formula
				     {
				       BEGIN(yyextra->lastCommentContext);
				     }
				     else if (&yytext[4]==yyextra->blockName)
				     {
				       BEGIN(yyextra->lastCommentContext);
				     }
                                   }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 490 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->javaBlock==0)
				     {
				       REJECT;
				     }
				     else
				     {
				       yyextra->javaBlock++;
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
				     }
                                   }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 501 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->javaBlock==0)
				     {
				       REJECT;
				     }
				     else
				     {
				       yyextra->javaBlock--;
				       if (yyextra->javaBlock==0)
				       {
                                         copyToOutput(yyscanner," @endcode ",10);
				         BEGIN(yyextra->lastCommentContext);
				       }
				       else
				       {
                                         copyToOutput(yyscanner,yytext,(int)yyleng);
				       }
				     }
  				   }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 520 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* end of markdown code block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                     if (yytext[0]==yyextra->blockName[0])
                                     {
                                       BEGIN(yyextra->lastCommentContext);
                                     }
                                   }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 527 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* end of verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
				     if (&yytext[4]==yyextra->blockName)
				     {
				       BEGIN(yyextra->lastCommentContext);
				     }
                                   }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 534 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* skip leading comments */
  				     if (!yyextra->inSpecialComment)
				     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng); 
				     }
                                     else
                                     {
                                       int l=0;
                                       while (yytext[l]==' ' || yytext[l]=='\t')
                                       {
                                         l++;
                                       }
                                       copyToOutput(yyscanner,yytext,l);
                                       if (yyleng-l==3) // ends with //! or ///
                                       {
                                         copyToOutput(yyscanner," * ",3);
                                       }
                                       else // ends with //
                                       {
                                         copyToOutput(yyscanner,"//",2);
                                       }
                                     }
  				   }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 557 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* any character not a backslash or new line or } */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 560 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* new line in verbatim block */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 563 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
  				     if (yyextra->blockName=="dot" || yyextra->blockName=="msc" || yyextra->blockName=="uml" || yyextra->blockName.at(0)=='f')
				     {
				       // see bug 487871, strip /// from dot images and formulas.
                                       int l=0;
                                       while (yytext[l]==' ' || yytext[l]=='\t')
                                       {
                                         l++;
                                       }
                                       copyToOutput(yyscanner,yytext,l);
				       copyToOutput(yyscanner,"   ",3);
				     }
				     else // even slashes are verbatim (e.g. \verbatim, \code)
				     {
				       REJECT;
				     }
  				   }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 580 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* any other character */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 583 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* escaped character in string */
                                     if (yyextra->lang==SrcLangExt_Fortran || yyextra->lang==SrcLangExt_VHDL)
                                     {
                                       unput(yytext[1]);
                                       copyToOutput(yyscanner,yytext,1);
                                     }
                                     else
                                     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
                                     }
                                   }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 594 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* end of string */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     BEGIN(yyextra->stringContext); 
                                   }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 598 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* any other string character */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 46:
/* rule 46 can match eol */
YY_RULE_SETUP
#line 601 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* new line inside string (illegal for some compilers) */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 604 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* escaped character */
                                     if (yyextra->lang==SrcLangExt_Fortran || yyextra->lang==SrcLangExt_VHDL)
                                     {
                                       unput(yytext[1]);
                                       copyToOutput(yyscanner,yytext,1);
                                     }
                                     else
                                     {
                                       copyToOutput(yyscanner,yytext,(int)yyleng);
                                     }
                                   }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 615 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* end of character literal */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                     BEGIN(yyextra->charContext);
                                   }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 619 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* any other string character */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 50:
/* rule 50 can match eol */
YY_RULE_SETUP
#line 622 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* new line character */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 626 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* anything that is not a '*' or command */ 
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 629 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* stars without slashes */
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
                                   }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 632 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* end of Python docstring */
                                     if (yyextra->lang!=SrcLangExt_Python)
				     {
				       REJECT;
				     }
				     else
				     {
                                       yyextra->nestingCount--;
                                       yyextra->pythonDocString = FALSE;
				       copyToOutput(yyscanner,yytext,(int)yyleng);
				       BEGIN(Scan);
				     }
  				   }
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
#line 645 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* new line in comment */
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                     /* in case of Fortran always end of comment */
  				     if (yyextra->lang==SrcLangExt_Fortran)
				     {
				       BEGIN(Scan);
				     }
                                   }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 653 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* nested C comment */
                                     if (yyextra->lang==SrcLangExt_Python ||
                                         yyextra->lang==SrcLangExt_Markdown)
				     {
				       REJECT;
                                     }
                                     yyextra->nestingCount++;
                                     yyextra->commentStack.push(yyextra->lineNr);
                                     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 663 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* end of C comment */
                                     if (yyextra->lang==SrcLangExt_Python ||
                                         yyextra->lang==SrcLangExt_Markdown)
				     {
				       REJECT;
				     }
				     else
				     {
				       copyToOutput(yyscanner,yytext,(int)yyleng);
                                       yyextra->nestingCount--;
                                       if (yyextra->nestingCount<=0)
                                       {
				         BEGIN(Scan);
                                       }
                                       else
                                       {
                                         //yyextra->nestingCount--;
                                         yyextra->commentStack.pop();
                                       }
				     }
                                   }
	YY_BREAK
/* Python an VHDL share CComment,CNComment, so special attention for ending comments is required */
case 57:
/* rule 57 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 685 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lang!=SrcLangExt_VHDL)
                                     {
                                       REJECT;
                                     }
                                     else
                                     {
                                       if (yyextra->vhdl) // inside --! comment
                                       {
                                         yyextra->vhdl = FALSE;
				         copyToOutput(yyscanner,yytext,(int)yyleng);
				         BEGIN(Scan);
                                       }
                                       else // C-type comment
                                       {
                                         REJECT;
                                       }
                                     }
                                   }
	YY_BREAK
case 58:
/* rule 58 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 704 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lang!=SrcLangExt_Python || yyextra->pythonDocString)
				     {
				       REJECT;
				     }
				     else
				     {
				       copyToOutput(yyscanner,yytext,(int)yyleng);
				       BEGIN(Scan);
				     }
                                   }
	YY_BREAK
case 59:
/* rule 59 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 1);
yyg->yy_c_buf_p = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 715 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lang==SrcLangExt_Python)
                                     {
                                       if (yyextra->pythonDocString)
                                       {
                                         REJECT;
                                       }
                                       else
                                       {
				         copyToOutput(yyscanner,yytext,(int)yyleng);
				         BEGIN(Scan);
                                       }
                                     }
                                     else if (yyextra->lang==SrcLangExt_VHDL)
                                     {
                                       if (yyextra->vhdl) // inside --! comment
                                       {
                                         yyextra->vhdl = FALSE;
				         copyToOutput(yyscanner,yytext,(int)yyleng);
				         BEGIN(Scan);
                                       }
                                       else // C-type comment
                                       {
                                         REJECT;
                                       }
                                     }
                                     else
                                     {
				       REJECT;
                                     }
                                   }
	YY_BREAK
/* removed for bug 674842 (bug was introduced in rev 768)
<CComment,CNComment>"'"			   {
  			             yyextra->charContext = YY_START;
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				     BEGIN(SkipChar);
  				   }
<CComment,CNComment>"\""			   {
  			             yyextra->stringContext = YY_START;
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				     BEGIN(SkipString);
  				   }
   */
case 60:
YY_RULE_SETUP
#line 758 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     copyToOutput(yyscanner,yytext,(int)yyleng); 
  				   }
	YY_BREAK
case 61:
/* rule 61 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 761 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
  				     replaceComment(yyscanner,0);
  				   }
	YY_BREAK
case 62:
/* rule 62 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 764 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     replaceComment(yyscanner,1); 
                                   }
	YY_BREAK
case 63:
/* rule 63 can match eol */
YY_RULE_SETUP
#line 767 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ 
  				     replaceComment(yyscanner,0);
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
  				   }
	YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
#line 772 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{   
                                     /* See Bug 752712: end the multiline comment when finding a @} or \} command */
                                     copyToOutput(yyscanner," */",3); 
				     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->inSpecialComment=FALSE;
				     yyextra->inRoseComment=FALSE;
				     BEGIN(Scan); 
                                   }
	YY_BREAK
case 65:
/* rule 65 can match eol */
YY_RULE_SETUP
#line 780 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ 
                                     replaceComment(yyscanner,1); 
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
  				   }
	YY_BREAK
case 66:
#line 786 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
case 67:
/* rule 67 can match eol */
#line 787 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
#line 787 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{    // or   //!something
  				     replaceComment(yyscanner,0);
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
                                   }
	YY_BREAK
case 69:
/* rule 69 can match eol */
#line 793 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
case 70:
/* rule 70 can match eol */
#line 794 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
case 71:
/* rule 71 can match eol */
YY_RULE_SETUP
#line 794 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ 
                                     replaceComment(yyscanner,1); 
				     yyextra->readLineCtx=YY_START;
				     BEGIN(ReadLine);
                                   }
	YY_BREAK
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
#line 799 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (!yyextra->inRoseComment)
				     {
				       REJECT;
				     }
				     else
				     {
  				       replaceComment(yyscanner,0);
				       yyextra->readLineCtx=YY_START;
				       BEGIN(ReadLine);
				     }
                                   }
	YY_BREAK
case 73:
/* rule 73 can match eol */
YY_RULE_SETUP
#line 811 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (!yyextra->inRoseComment)
				     {
				       REJECT;
				     }
				     else
				     {
                                       replaceComment(yyscanner,1); 
				       yyextra->readLineCtx=YY_START;
				       BEGIN(ReadLine);
				     }
                                   }
	YY_BREAK
case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
#line 823 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ /* end of special comment */
                                     copyToOutput(yyscanner," */",3); 
				     copyToOutput(yyscanner,yytext,(int)yyleng); 
				     yyextra->inSpecialComment=FALSE;
				     yyextra->inRoseComment=FALSE;
				     BEGIN(Scan); 
                                   }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 830 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
				     copyToOutput(yyscanner,"/&zwj;**",8);
				   }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 833 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
				     copyToOutput(yyscanner,"*&zwj;/",7);
				   }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 836 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				   }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 839 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				   }
	YY_BREAK
case 79:
/* rule 79 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 842 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
				     copyToOutput(yyscanner,yytext,(int)yyleng);
				     BEGIN(yyextra->readLineCtx);
				   }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 846 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // escaped command
				     copyToOutput(yyscanner,yytext,(int)yyleng);
  				   }
	YY_BREAK
case 81:
/* rule 81 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 5);
yyg->yy_c_buf_p = yy_cp = yy_bp + 5;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 849 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // conditional section
  				     yyextra->condCtx = YY_START; 
  				     BEGIN(CondLine);
  				   }
	YY_BREAK
case 82:
/* rule 82 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_bp + 8);
yyg->yy_c_buf_p = yy_cp = yy_bp + 8;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 853 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // end of conditional section
  				     bool oldSkip=yyextra->skip;
  				     endCondSection(yyscanner);
				     if (YY_START==CComment && oldSkip && !yyextra->skip) 
    			             {
				       //printf("** Adding start of comment!\n");
				       if (yyextra->lang!=SrcLangExt_Python &&
					   yyextra->lang!=SrcLangExt_VHDL &&
					   yyextra->lang!=SrcLangExt_Markdown &&
					   yyextra->lang!=SrcLangExt_Fortran)
				       {
 				         ADDCHAR('/');
     				         ADDCHAR('*');
					 if (yyextra->specialComment)
					 {
					   ADDCHAR('*');
					 }
				       }
    				     }
				    }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 873 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     handleCondSectionId(yyscanner,yytext);
  				   }
	YY_BREAK
case 84:
/* rule 84 can match eol */
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 876 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
  				     yyextra->condCtx=YY_START;
                                     handleCondSectionId(yyscanner," "); // fake section id causing the section to be hidden unconditionally
                                   }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 880 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // forgot section id?
                                     handleCondSectionId(yyscanner," "); // fake section id causing the section to be hidden unconditionally
				     if (*yytext=='\n') yyextra->lineNr++;
  				   }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 884 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // expand alias without arguments
				     replaceAliases(yyscanner,QCString(yytext));
  				   }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 887 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // expand alias with arguments
                                     yyextra->lastBlockContext=YY_START;
				     yyextra->blockCount=1;
				     yyextra->aliasString=yytext;
				     yyextra->lastEscaped=0;
				     BEGIN( ReadAliasArgs );
  				   }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 894 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // skip leading special comments (see bug 618079)
  				   }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 896 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{ // oops, end of comment in the middle of an alias?
                                     if (yyextra->lang==SrcLangExt_Python)
				     {
				       REJECT;
				     }
				     else // abort the alias, restart scanning
				     {
				       copyToOutput(yyscanner,yyextra->aliasString.data(),yyextra->aliasString.length());
				       copyToOutput(yyscanner,yytext,(int)yyleng);
				       BEGIN(Scan);
				     }
  				   }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 908 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     yyextra->aliasString+=yytext;
				     yyextra->lastEscaped=FALSE;
  				   }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 912 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     if (yyextra->lastEscaped)  yyextra->lastEscaped=FALSE;
                                     else                yyextra->lastEscaped=TRUE;
                                     yyextra->aliasString+=yytext;
                                   }
	YY_BREAK
case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 917 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     yyextra->aliasString+=yytext;
                                     yyextra->lineNr++;
				     yyextra->lastEscaped=FALSE;
  				   }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 922 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     yyextra->aliasString+=yytext;
                                     if (!yyextra->lastEscaped) yyextra->blockCount++;
				     yyextra->lastEscaped=FALSE;
                                   }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 927 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     yyextra->aliasString+=yytext;
				     if (!yyextra->lastEscaped) yyextra->blockCount--;
				     if (yyextra->blockCount==0)
				     {
				       replaceAliases(yyscanner,yyextra->aliasString);
				       BEGIN( yyextra->lastBlockContext );
				     }
				     yyextra->lastEscaped=FALSE;
  			           }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 937 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
                                     yyextra->aliasString+=yytext;
				     yyextra->lastEscaped=FALSE;
  				   }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 941 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
  				     copyToOutput(yyscanner,yytext,(int)yyleng);
  				   }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 945 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
{
  				     copyToOutput(yyscanner,yytext,(int)yyleng);
                                   }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 948 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"
ECHO;
	YY_BREAK
#line 3666 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/build/generated_src/commentcnv.cpp"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(Scan):
			case YY_STATE_EOF(SkipString):
			case YY_STATE_EOF(SkipChar):
			case YY_STATE_EOF(SComment):
			case YY_STATE_EOF(CComment):
			case YY_STATE_EOF(CNComment):
			case YY_STATE_EOF(Verbatim):
			case YY_STATE_EOF(VerbatimCode):
			case YY_STATE_EOF(ReadLine):
			case YY_STATE_EOF(CondLine):
			case YY_STATE_EOF(ReadAliasArgs):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 619 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 619 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 618);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 948 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.2-2.i686/src/doxygen-1.9.2/src/commentcnv.l"


static void replaceCommentMarker(yyscan_t yyscanner,const char *s,int len)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  const char *p=s;
  char c;
  // copy leading blanks
  while ((c=*p) && (c==' ' || c=='\t' || c=='\n')) 
  {
    ADDCHAR(c);
    yyextra->lineNr += c=='\n';
    p++;
  }
  // replace start of comment marker by blanks and the last character by a *
  int blanks=0;
  while ((c=*p) && (c=='/' || c=='!' || c=='#')) 
  {
    blanks++;
    p++;
    if (*p=='<') // comment-after-item marker 
    { 
      blanks++;
      p++; 
    }
    if (c=='!') // end after first !
    {
      break;
    }
  }
  if (blanks>0)
  {
    while (blanks>2)
    {
      ADDCHAR(' ');
      blanks--;
    }
    if (blanks>1) ADDCHAR('*');
    ADDCHAR(' ');
  }
  // copy comment line to output
  ADDARRAY(p,len-(int)(p-s));
}

static inline int computeIndent(const char *s)
{
  int col=0;
  static int tabSize=Config_getInt(TAB_SIZE);
  const char *p=s;
  char c;
  while ((c=*p++))
  {
    if (c==' ') col++;
    else if (c=='\t') col+=tabSize-(col%tabSize); 
    else break;
  }
  return col;
}

static inline void copyToOutput(yyscan_t yyscanner,const char *s,int len)
{
  int tabSize=Config_getInt(TAB_SIZE);
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  int i;
  if (yyextra->skip) // only add newlines.
  {
    for (i=0;i<len;i++)
    {
      switch(s[i])
      {
        case '\n':
	  ADDCHAR('\n');
	  yyextra->lineNr++;
          yyextra->col=0;
          break;
        case '\t':
          yyextra->col+=tabSize-(yyextra->col%tabSize);
          break;
        default:
          yyextra->col++;
          break;
      }
    }
  }
  else if (len>0)
  {
    ADDARRAY(s,len);
    for (i=0;i<len;i++) 
    {
      switch (s[i])
      {
	case '\n': yyextra->col=0; 
	           //fprintf(stderr,"---> copy %d\n",g_lineNr);
		   yyextra->lineNr++; break;
	case '\t': yyextra->col+=tabSize-(yyextra->col%tabSize); break;
	default:   yyextra->col++; break;
      }
    }
  }
}

static void clearCommentStack(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  while (!yyextra->commentStack.empty()) yyextra->commentStack.pop();
}

static void startCondSection(yyscan_t yyscanner,const QCString &sectId)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  //printf("startCondSection: skip=%d stack=%d\n",g_skip,g_condStack.count());
  CondParser prs;
  bool expResult = prs.parse(yyextra->fileName,yyextra->lineNr,sectId);
  yyextra->condStack.push(CondCtx(yyextra->lineNr,sectId,yyextra->skip));
  if (!expResult) // not enabled
  {
    yyextra->skip=TRUE;
  }
}

static void endCondSection(yyscan_t yyscanner)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  if (yyextra->condStack.empty())
  {
    warn(yyextra->fileName,yyextra->lineNr,"Found \\endcond command without matching \\cond");
    yyextra->skip=FALSE;
  }
  else
  {
    const CondCtx &ctx = yyextra->condStack.top();
    yyextra->skip=ctx.skip;
    yyextra->condStack.pop();
  }
  //printf("endCondSection: skip=%d stack=%d\n",g_skip,g_condStack.count());
}

static void handleCondSectionId(yyscan_t yyscanner,const char *expression)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  bool oldSkip=yyextra->skip;
  startCondSection(yyscanner,QCString(expression));
  if ((yyextra->condCtx==CComment || yyextra->readLineCtx==SComment) && 
      !oldSkip && yyextra->skip) 
  {
    if (yyextra->lang!=SrcLangExt_Python &&
        yyextra->lang!=SrcLangExt_VHDL &&
        yyextra->lang!=SrcLangExt_Markdown &&
        yyextra->lang!=SrcLangExt_Fortran)
    {
      ADDCHAR('*');
      ADDCHAR('/');
    }
  }
  if (yyextra->readLineCtx==SComment)
  {
    BEGIN(SComment);
  }
  else
  {
    BEGIN(yyextra->condCtx);
  }
}

/** copies string \a s with length \a len to the output, while 
 *  replacing any alias commands found in the string.
 */
static void replaceAliases(yyscan_t yyscanner,const QCString &s)
{
  QCString result = resolveAliasCmd(s);
  //printf("replaceAliases(%s)->'%s'\n",s,result.data());
  copyToOutput(yyscanner,result.data(),result.length());
}


static yy_size_t yyread(yyscan_t yyscanner,char *buf,yy_size_t max_size)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  yy_size_t bytesInBuf = yyextra->inBuf->curPos()-yyextra->inBufPos;
  yy_size_t bytesToCopy = std::min(max_size,bytesInBuf);
  memcpy(buf,yyextra->inBuf->data()+yyextra->inBufPos,bytesToCopy);
  yyextra->inBufPos+=bytesToCopy;
  return bytesToCopy;
}

static void replaceComment(yyscan_t yyscanner,int offset)
{
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  if (yyextra->mlBrief || yyextra->skip)
  {
    copyToOutput(yyscanner,yytext,(int)yyleng);
  }
  else
  {
    //printf("replaceComment(%s)\n",yytext);
    int i=computeIndent(&yytext[offset]);
    if (i==yyextra->blockHeadCol)
    {
      replaceCommentMarker(yyscanner,yytext,(int)yyleng);
    }
    else
    {
      copyToOutput(yyscanner," */",3);
      for (i=(int)yyleng-1;i>=0;i--) unput(yytext[i]);
      yyextra->inSpecialComment=FALSE;
      BEGIN(Scan);
    }
  }
}

/*! This function does three things:
 *  -# It converts multi-line C++ style comment blocks (that are aligned)
 *     to C style comment blocks (if MULTILINE_CPP_IS_BRIEF is set to NO).
 *  -# It replaces aliases with their definition (see ALIASES)
 *  -# It handles conditional sections (cond...endcond blocks)
 */
void convertCppComments(BufStr *inBuf,BufStr *outBuf,const QCString &fileName)
{
  yyscan_t yyscanner;
  commentcnvYY_state extra;
  commentcnvYYlex_init_extra(&extra,&yyscanner);
#ifdef FLEX_DEBUG
  commentcnvYYset_debug(1,yyscanner);
#endif
  struct yyguts_t *yyg = (struct yyguts_t*)yyscanner;
  //printf("convertCppComments(%s)\n",fileName);
  yyextra->inBuf    = inBuf;
  yyextra->outBuf   = outBuf;
  yyextra->inBufPos = 0;
  yyextra->col      = 0;
  yyextra->mlBrief = Config_getBool(MULTILINE_CPP_IS_BRIEF);
  yyextra->skip     = FALSE;
  yyextra->fileName = fileName;
  yyextra->lang = getLanguageFromFileName(fileName);
  yyextra->pythonDocString = FALSE;
  yyextra->lineNr   = 1;
  while (!yyextra->condStack.empty()) yyextra->condStack.pop();
  clearCommentStack(yyscanner);
  yyextra->vhdl = FALSE;

  printlex(yy_flex_debug, TRUE, __FILE__, qPrint(fileName));
  yyextra->isFixedForm = FALSE;
  if (yyextra->lang==SrcLangExt_Fortran)
  {
    FortranFormat fmt = convertFileNameFortranParserCode(fileName);
    yyextra->isFixedForm = recognizeFixedForm(QCString(inBuf->data()),fmt);
  }

  if (yyextra->lang==SrcLangExt_Markdown)
  {
    yyextra->nestingCount=0;
    BEGIN(CComment);
    yyextra->commentStack.push(yyextra->lineNr);
  }
  else
  {
    BEGIN(Scan);
  }
  yylex(yyscanner);
  while (!yyextra->condStack.empty())
  {
    const CondCtx &ctx = yyextra->condStack.top();
    QCString sectionInfo(" ");
    if (ctx.sectionId!=" ") sectionInfo.sprintf(" with label '%s' ",ctx.sectionId.stripWhiteSpace().data());
    warn(yyextra->fileName,ctx.lineNr,"Conditional section%sdoes not have "
	"a corresponding \\endcond command within this file.",sectionInfo.data());
    yyextra->condStack.pop();
  }
  if (yyextra->nestingCount>0 && yyextra->lang!=SrcLangExt_Markdown && yyextra->lang!=SrcLangExt_Fortran)
  {
    QCString tmp("(probable line reference: ");
    bool first = TRUE;
    while (!yyextra->commentStack.empty())
    {
      int lineNr = yyextra->commentStack.top();
      if (!first) tmp += ", ";
      tmp += QCString().setNum(lineNr);
      first = FALSE;
      yyextra->commentStack.pop();
    }
    tmp += ")";
    warn(yyextra->fileName,yyextra->lineNr,"Reached end of file while still inside a (nested) comment. "
        "Nesting level %d %s",yyextra->nestingCount,tmp.data());
  }
  yyextra->nestingCount = 0;
  if (Debug::isFlagSet(Debug::CommentCnv))
  {
    yyextra->outBuf->at(yyextra->outBuf->curPos())='\0';
    Debug::print(Debug::CommentCnv,0,"-----------\nCommentCnv: %s\n"
                 "output=[\n%s]\n-----------\n",qPrint(fileName),yyextra->outBuf->data()
                );
  }
  printlex(yy_flex_debug, FALSE, __FILE__, qPrint(fileName));
  commentcnvYYlex_destroy(yyscanner);
}


//----------------------------------------------------------------------------

#if USE_STATE2STRING
#include "commentcnv.l.h"
#endif

